# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FirewallSettingsArgs', 'FirewallSettings']

@pulumi.input_type
class FirewallSettingsArgs:
    def __init__(__self__, *,
                 default_firewall_ids: Optional[pulumi.Input['FirewallSettingsDefaultFirewallIdsArgs']] = None):
        """
        The set of arguments for constructing a FirewallSettings resource.
        :param pulumi.Input['FirewallSettingsDefaultFirewallIdsArgs'] default_firewall_ids: A map of default firewall IDs for various interfaces.
        """
        if default_firewall_ids is not None:
            pulumi.set(__self__, "default_firewall_ids", default_firewall_ids)

    @_builtins.property
    @pulumi.getter(name="defaultFirewallIds")
    def default_firewall_ids(self) -> Optional[pulumi.Input['FirewallSettingsDefaultFirewallIdsArgs']]:
        """
        A map of default firewall IDs for various interfaces.
        """
        return pulumi.get(self, "default_firewall_ids")

    @default_firewall_ids.setter
    def default_firewall_ids(self, value: Optional[pulumi.Input['FirewallSettingsDefaultFirewallIdsArgs']]):
        pulumi.set(self, "default_firewall_ids", value)


@pulumi.input_type
class _FirewallSettingsState:
    def __init__(__self__, *,
                 default_firewall_ids: Optional[pulumi.Input['FirewallSettingsDefaultFirewallIdsArgs']] = None):
        """
        Input properties used for looking up and filtering FirewallSettings resources.
        :param pulumi.Input['FirewallSettingsDefaultFirewallIdsArgs'] default_firewall_ids: A map of default firewall IDs for various interfaces.
        """
        if default_firewall_ids is not None:
            pulumi.set(__self__, "default_firewall_ids", default_firewall_ids)

    @_builtins.property
    @pulumi.getter(name="defaultFirewallIds")
    def default_firewall_ids(self) -> Optional[pulumi.Input['FirewallSettingsDefaultFirewallIdsArgs']]:
        """
        A map of default firewall IDs for various interfaces.
        """
        return pulumi.get(self, "default_firewall_ids")

    @default_firewall_ids.setter
    def default_firewall_ids(self, value: Optional[pulumi.Input['FirewallSettingsDefaultFirewallIdsArgs']]):
        pulumi.set(self, "default_firewall_ids", value)


@pulumi.type_token("linode:index/firewallSettings:FirewallSettings")
class FirewallSettings(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_firewall_ids: Optional[pulumi.Input[Union['FirewallSettingsDefaultFirewallIdsArgs', 'FirewallSettingsDefaultFirewallIdsArgsDict']]] = None,
                 __props__=None):
        """
        Manages Linode account-level firewall settings. Resetting default firewall IDs
        to null is not available to all customers and unsupported in this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_linode as linode

        example = linode.FirewallSettings("example", default_firewall_ids={
            "linode": 12345,
            "nodebalancer": 12345,
            "public_interface": 12345,
            "vpc_interface": 12345,
        })
        ```

        ## API Reference

        See the [Linode API documentation](https://techdocs.akamai.com/linode-api/reference/put-firewall-settings) for more details.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['FirewallSettingsDefaultFirewallIdsArgs', 'FirewallSettingsDefaultFirewallIdsArgsDict']] default_firewall_ids: A map of default firewall IDs for various interfaces.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[FirewallSettingsArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Linode account-level firewall settings. Resetting default firewall IDs
        to null is not available to all customers and unsupported in this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_linode as linode

        example = linode.FirewallSettings("example", default_firewall_ids={
            "linode": 12345,
            "nodebalancer": 12345,
            "public_interface": 12345,
            "vpc_interface": 12345,
        })
        ```

        ## API Reference

        See the [Linode API documentation](https://techdocs.akamai.com/linode-api/reference/put-firewall-settings) for more details.

        :param str resource_name: The name of the resource.
        :param FirewallSettingsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FirewallSettingsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_firewall_ids: Optional[pulumi.Input[Union['FirewallSettingsDefaultFirewallIdsArgs', 'FirewallSettingsDefaultFirewallIdsArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FirewallSettingsArgs.__new__(FirewallSettingsArgs)

            __props__.__dict__["default_firewall_ids"] = default_firewall_ids
        super(FirewallSettings, __self__).__init__(
            'linode:index/firewallSettings:FirewallSettings',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            default_firewall_ids: Optional[pulumi.Input[Union['FirewallSettingsDefaultFirewallIdsArgs', 'FirewallSettingsDefaultFirewallIdsArgsDict']]] = None) -> 'FirewallSettings':
        """
        Get an existing FirewallSettings resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['FirewallSettingsDefaultFirewallIdsArgs', 'FirewallSettingsDefaultFirewallIdsArgsDict']] default_firewall_ids: A map of default firewall IDs for various interfaces.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FirewallSettingsState.__new__(_FirewallSettingsState)

        __props__.__dict__["default_firewall_ids"] = default_firewall_ids
        return FirewallSettings(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="defaultFirewallIds")
    def default_firewall_ids(self) -> pulumi.Output[Optional['outputs.FirewallSettingsDefaultFirewallIds']]:
        """
        A map of default firewall IDs for various interfaces.
        """
        return pulumi.get(self, "default_firewall_ids")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetDatabasePostgresqlV2Result',
    'AwaitableGetDatabasePostgresqlV2Result',
    'get_database_postgresql_v2',
    'get_database_postgresql_v2_output',
]

@pulumi.output_type
class GetDatabasePostgresqlV2Result:
    """
    A collection of values returned by getDatabasePostgresqlV2.
    """
    def __init__(__self__, allow_lists=None, ca_cert=None, cluster_size=None, created=None, encrypted=None, engine=None, engine_config_pg_autovacuum_analyze_scale_factor=None, engine_config_pg_autovacuum_analyze_threshold=None, engine_config_pg_autovacuum_max_workers=None, engine_config_pg_autovacuum_naptime=None, engine_config_pg_autovacuum_vacuum_cost_delay=None, engine_config_pg_autovacuum_vacuum_cost_limit=None, engine_config_pg_autovacuum_vacuum_scale_factor=None, engine_config_pg_autovacuum_vacuum_threshold=None, engine_config_pg_bgwriter_delay=None, engine_config_pg_bgwriter_flush_after=None, engine_config_pg_bgwriter_lru_maxpages=None, engine_config_pg_bgwriter_lru_multiplier=None, engine_config_pg_deadlock_timeout=None, engine_config_pg_default_toast_compression=None, engine_config_pg_idle_in_transaction_session_timeout=None, engine_config_pg_jit=None, engine_config_pg_max_files_per_process=None, engine_config_pg_max_locks_per_transaction=None, engine_config_pg_max_logical_replication_workers=None, engine_config_pg_max_parallel_workers=None, engine_config_pg_max_parallel_workers_per_gather=None, engine_config_pg_max_pred_locks_per_transaction=None, engine_config_pg_max_replication_slots=None, engine_config_pg_max_slot_wal_keep_size=None, engine_config_pg_max_stack_depth=None, engine_config_pg_max_standby_archive_delay=None, engine_config_pg_max_standby_streaming_delay=None, engine_config_pg_max_wal_senders=None, engine_config_pg_max_worker_processes=None, engine_config_pg_password_encryption=None, engine_config_pg_pg_partman_bgw_interval=None, engine_config_pg_pg_partman_bgw_role=None, engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan=None, engine_config_pg_pg_stat_monitor_pgsm_max_buckets=None, engine_config_pg_pg_stat_statements_track=None, engine_config_pg_stat_monitor_enable=None, engine_config_pg_temp_file_limit=None, engine_config_pg_timezone=None, engine_config_pg_track_activity_query_size=None, engine_config_pg_track_commit_timestamp=None, engine_config_pg_track_functions=None, engine_config_pg_track_io_timing=None, engine_config_pg_wal_sender_timeout=None, engine_config_pg_wal_writer_delay=None, engine_config_pglookout_max_failover_replication_time_lag=None, engine_config_shared_buffers_percentage=None, engine_config_work_mem=None, engine_id=None, fork_restore_time=None, fork_source=None, host_primary=None, host_secondary=None, id=None, label=None, members=None, oldest_restore_time=None, pending_updates=None, platform=None, port=None, private_network=None, region=None, root_password=None, root_username=None, ssl_connection=None, status=None, suspended=None, type=None, updated=None, updates=None, version=None):
        if allow_lists and not isinstance(allow_lists, list):
            raise TypeError("Expected argument 'allow_lists' to be a list")
        pulumi.set(__self__, "allow_lists", allow_lists)
        if ca_cert and not isinstance(ca_cert, str):
            raise TypeError("Expected argument 'ca_cert' to be a str")
        pulumi.set(__self__, "ca_cert", ca_cert)
        if cluster_size and not isinstance(cluster_size, int):
            raise TypeError("Expected argument 'cluster_size' to be a int")
        pulumi.set(__self__, "cluster_size", cluster_size)
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if encrypted and not isinstance(encrypted, bool):
            raise TypeError("Expected argument 'encrypted' to be a bool")
        pulumi.set(__self__, "encrypted", encrypted)
        if engine and not isinstance(engine, str):
            raise TypeError("Expected argument 'engine' to be a str")
        pulumi.set(__self__, "engine", engine)
        if engine_config_pg_autovacuum_analyze_scale_factor and not isinstance(engine_config_pg_autovacuum_analyze_scale_factor, float):
            raise TypeError("Expected argument 'engine_config_pg_autovacuum_analyze_scale_factor' to be a float")
        pulumi.set(__self__, "engine_config_pg_autovacuum_analyze_scale_factor", engine_config_pg_autovacuum_analyze_scale_factor)
        if engine_config_pg_autovacuum_analyze_threshold and not isinstance(engine_config_pg_autovacuum_analyze_threshold, int):
            raise TypeError("Expected argument 'engine_config_pg_autovacuum_analyze_threshold' to be a int")
        pulumi.set(__self__, "engine_config_pg_autovacuum_analyze_threshold", engine_config_pg_autovacuum_analyze_threshold)
        if engine_config_pg_autovacuum_max_workers and not isinstance(engine_config_pg_autovacuum_max_workers, int):
            raise TypeError("Expected argument 'engine_config_pg_autovacuum_max_workers' to be a int")
        pulumi.set(__self__, "engine_config_pg_autovacuum_max_workers", engine_config_pg_autovacuum_max_workers)
        if engine_config_pg_autovacuum_naptime and not isinstance(engine_config_pg_autovacuum_naptime, int):
            raise TypeError("Expected argument 'engine_config_pg_autovacuum_naptime' to be a int")
        pulumi.set(__self__, "engine_config_pg_autovacuum_naptime", engine_config_pg_autovacuum_naptime)
        if engine_config_pg_autovacuum_vacuum_cost_delay and not isinstance(engine_config_pg_autovacuum_vacuum_cost_delay, int):
            raise TypeError("Expected argument 'engine_config_pg_autovacuum_vacuum_cost_delay' to be a int")
        pulumi.set(__self__, "engine_config_pg_autovacuum_vacuum_cost_delay", engine_config_pg_autovacuum_vacuum_cost_delay)
        if engine_config_pg_autovacuum_vacuum_cost_limit and not isinstance(engine_config_pg_autovacuum_vacuum_cost_limit, int):
            raise TypeError("Expected argument 'engine_config_pg_autovacuum_vacuum_cost_limit' to be a int")
        pulumi.set(__self__, "engine_config_pg_autovacuum_vacuum_cost_limit", engine_config_pg_autovacuum_vacuum_cost_limit)
        if engine_config_pg_autovacuum_vacuum_scale_factor and not isinstance(engine_config_pg_autovacuum_vacuum_scale_factor, float):
            raise TypeError("Expected argument 'engine_config_pg_autovacuum_vacuum_scale_factor' to be a float")
        pulumi.set(__self__, "engine_config_pg_autovacuum_vacuum_scale_factor", engine_config_pg_autovacuum_vacuum_scale_factor)
        if engine_config_pg_autovacuum_vacuum_threshold and not isinstance(engine_config_pg_autovacuum_vacuum_threshold, int):
            raise TypeError("Expected argument 'engine_config_pg_autovacuum_vacuum_threshold' to be a int")
        pulumi.set(__self__, "engine_config_pg_autovacuum_vacuum_threshold", engine_config_pg_autovacuum_vacuum_threshold)
        if engine_config_pg_bgwriter_delay and not isinstance(engine_config_pg_bgwriter_delay, int):
            raise TypeError("Expected argument 'engine_config_pg_bgwriter_delay' to be a int")
        pulumi.set(__self__, "engine_config_pg_bgwriter_delay", engine_config_pg_bgwriter_delay)
        if engine_config_pg_bgwriter_flush_after and not isinstance(engine_config_pg_bgwriter_flush_after, int):
            raise TypeError("Expected argument 'engine_config_pg_bgwriter_flush_after' to be a int")
        pulumi.set(__self__, "engine_config_pg_bgwriter_flush_after", engine_config_pg_bgwriter_flush_after)
        if engine_config_pg_bgwriter_lru_maxpages and not isinstance(engine_config_pg_bgwriter_lru_maxpages, int):
            raise TypeError("Expected argument 'engine_config_pg_bgwriter_lru_maxpages' to be a int")
        pulumi.set(__self__, "engine_config_pg_bgwriter_lru_maxpages", engine_config_pg_bgwriter_lru_maxpages)
        if engine_config_pg_bgwriter_lru_multiplier and not isinstance(engine_config_pg_bgwriter_lru_multiplier, float):
            raise TypeError("Expected argument 'engine_config_pg_bgwriter_lru_multiplier' to be a float")
        pulumi.set(__self__, "engine_config_pg_bgwriter_lru_multiplier", engine_config_pg_bgwriter_lru_multiplier)
        if engine_config_pg_deadlock_timeout and not isinstance(engine_config_pg_deadlock_timeout, int):
            raise TypeError("Expected argument 'engine_config_pg_deadlock_timeout' to be a int")
        pulumi.set(__self__, "engine_config_pg_deadlock_timeout", engine_config_pg_deadlock_timeout)
        if engine_config_pg_default_toast_compression and not isinstance(engine_config_pg_default_toast_compression, str):
            raise TypeError("Expected argument 'engine_config_pg_default_toast_compression' to be a str")
        pulumi.set(__self__, "engine_config_pg_default_toast_compression", engine_config_pg_default_toast_compression)
        if engine_config_pg_idle_in_transaction_session_timeout and not isinstance(engine_config_pg_idle_in_transaction_session_timeout, int):
            raise TypeError("Expected argument 'engine_config_pg_idle_in_transaction_session_timeout' to be a int")
        pulumi.set(__self__, "engine_config_pg_idle_in_transaction_session_timeout", engine_config_pg_idle_in_transaction_session_timeout)
        if engine_config_pg_jit and not isinstance(engine_config_pg_jit, bool):
            raise TypeError("Expected argument 'engine_config_pg_jit' to be a bool")
        pulumi.set(__self__, "engine_config_pg_jit", engine_config_pg_jit)
        if engine_config_pg_max_files_per_process and not isinstance(engine_config_pg_max_files_per_process, int):
            raise TypeError("Expected argument 'engine_config_pg_max_files_per_process' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_files_per_process", engine_config_pg_max_files_per_process)
        if engine_config_pg_max_locks_per_transaction and not isinstance(engine_config_pg_max_locks_per_transaction, int):
            raise TypeError("Expected argument 'engine_config_pg_max_locks_per_transaction' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_locks_per_transaction", engine_config_pg_max_locks_per_transaction)
        if engine_config_pg_max_logical_replication_workers and not isinstance(engine_config_pg_max_logical_replication_workers, int):
            raise TypeError("Expected argument 'engine_config_pg_max_logical_replication_workers' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_logical_replication_workers", engine_config_pg_max_logical_replication_workers)
        if engine_config_pg_max_parallel_workers and not isinstance(engine_config_pg_max_parallel_workers, int):
            raise TypeError("Expected argument 'engine_config_pg_max_parallel_workers' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_parallel_workers", engine_config_pg_max_parallel_workers)
        if engine_config_pg_max_parallel_workers_per_gather and not isinstance(engine_config_pg_max_parallel_workers_per_gather, int):
            raise TypeError("Expected argument 'engine_config_pg_max_parallel_workers_per_gather' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_parallel_workers_per_gather", engine_config_pg_max_parallel_workers_per_gather)
        if engine_config_pg_max_pred_locks_per_transaction and not isinstance(engine_config_pg_max_pred_locks_per_transaction, int):
            raise TypeError("Expected argument 'engine_config_pg_max_pred_locks_per_transaction' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_pred_locks_per_transaction", engine_config_pg_max_pred_locks_per_transaction)
        if engine_config_pg_max_replication_slots and not isinstance(engine_config_pg_max_replication_slots, int):
            raise TypeError("Expected argument 'engine_config_pg_max_replication_slots' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_replication_slots", engine_config_pg_max_replication_slots)
        if engine_config_pg_max_slot_wal_keep_size and not isinstance(engine_config_pg_max_slot_wal_keep_size, int):
            raise TypeError("Expected argument 'engine_config_pg_max_slot_wal_keep_size' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_slot_wal_keep_size", engine_config_pg_max_slot_wal_keep_size)
        if engine_config_pg_max_stack_depth and not isinstance(engine_config_pg_max_stack_depth, int):
            raise TypeError("Expected argument 'engine_config_pg_max_stack_depth' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_stack_depth", engine_config_pg_max_stack_depth)
        if engine_config_pg_max_standby_archive_delay and not isinstance(engine_config_pg_max_standby_archive_delay, int):
            raise TypeError("Expected argument 'engine_config_pg_max_standby_archive_delay' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_standby_archive_delay", engine_config_pg_max_standby_archive_delay)
        if engine_config_pg_max_standby_streaming_delay and not isinstance(engine_config_pg_max_standby_streaming_delay, int):
            raise TypeError("Expected argument 'engine_config_pg_max_standby_streaming_delay' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_standby_streaming_delay", engine_config_pg_max_standby_streaming_delay)
        if engine_config_pg_max_wal_senders and not isinstance(engine_config_pg_max_wal_senders, int):
            raise TypeError("Expected argument 'engine_config_pg_max_wal_senders' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_wal_senders", engine_config_pg_max_wal_senders)
        if engine_config_pg_max_worker_processes and not isinstance(engine_config_pg_max_worker_processes, int):
            raise TypeError("Expected argument 'engine_config_pg_max_worker_processes' to be a int")
        pulumi.set(__self__, "engine_config_pg_max_worker_processes", engine_config_pg_max_worker_processes)
        if engine_config_pg_password_encryption and not isinstance(engine_config_pg_password_encryption, str):
            raise TypeError("Expected argument 'engine_config_pg_password_encryption' to be a str")
        pulumi.set(__self__, "engine_config_pg_password_encryption", engine_config_pg_password_encryption)
        if engine_config_pg_pg_partman_bgw_interval and not isinstance(engine_config_pg_pg_partman_bgw_interval, int):
            raise TypeError("Expected argument 'engine_config_pg_pg_partman_bgw_interval' to be a int")
        pulumi.set(__self__, "engine_config_pg_pg_partman_bgw_interval", engine_config_pg_pg_partman_bgw_interval)
        if engine_config_pg_pg_partman_bgw_role and not isinstance(engine_config_pg_pg_partman_bgw_role, str):
            raise TypeError("Expected argument 'engine_config_pg_pg_partman_bgw_role' to be a str")
        pulumi.set(__self__, "engine_config_pg_pg_partman_bgw_role", engine_config_pg_pg_partman_bgw_role)
        if engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan and not isinstance(engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan, bool):
            raise TypeError("Expected argument 'engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan' to be a bool")
        pulumi.set(__self__, "engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan", engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan)
        if engine_config_pg_pg_stat_monitor_pgsm_max_buckets and not isinstance(engine_config_pg_pg_stat_monitor_pgsm_max_buckets, int):
            raise TypeError("Expected argument 'engine_config_pg_pg_stat_monitor_pgsm_max_buckets' to be a int")
        pulumi.set(__self__, "engine_config_pg_pg_stat_monitor_pgsm_max_buckets", engine_config_pg_pg_stat_monitor_pgsm_max_buckets)
        if engine_config_pg_pg_stat_statements_track and not isinstance(engine_config_pg_pg_stat_statements_track, str):
            raise TypeError("Expected argument 'engine_config_pg_pg_stat_statements_track' to be a str")
        pulumi.set(__self__, "engine_config_pg_pg_stat_statements_track", engine_config_pg_pg_stat_statements_track)
        if engine_config_pg_stat_monitor_enable and not isinstance(engine_config_pg_stat_monitor_enable, bool):
            raise TypeError("Expected argument 'engine_config_pg_stat_monitor_enable' to be a bool")
        pulumi.set(__self__, "engine_config_pg_stat_monitor_enable", engine_config_pg_stat_monitor_enable)
        if engine_config_pg_temp_file_limit and not isinstance(engine_config_pg_temp_file_limit, int):
            raise TypeError("Expected argument 'engine_config_pg_temp_file_limit' to be a int")
        pulumi.set(__self__, "engine_config_pg_temp_file_limit", engine_config_pg_temp_file_limit)
        if engine_config_pg_timezone and not isinstance(engine_config_pg_timezone, str):
            raise TypeError("Expected argument 'engine_config_pg_timezone' to be a str")
        pulumi.set(__self__, "engine_config_pg_timezone", engine_config_pg_timezone)
        if engine_config_pg_track_activity_query_size and not isinstance(engine_config_pg_track_activity_query_size, int):
            raise TypeError("Expected argument 'engine_config_pg_track_activity_query_size' to be a int")
        pulumi.set(__self__, "engine_config_pg_track_activity_query_size", engine_config_pg_track_activity_query_size)
        if engine_config_pg_track_commit_timestamp and not isinstance(engine_config_pg_track_commit_timestamp, str):
            raise TypeError("Expected argument 'engine_config_pg_track_commit_timestamp' to be a str")
        pulumi.set(__self__, "engine_config_pg_track_commit_timestamp", engine_config_pg_track_commit_timestamp)
        if engine_config_pg_track_functions and not isinstance(engine_config_pg_track_functions, str):
            raise TypeError("Expected argument 'engine_config_pg_track_functions' to be a str")
        pulumi.set(__self__, "engine_config_pg_track_functions", engine_config_pg_track_functions)
        if engine_config_pg_track_io_timing and not isinstance(engine_config_pg_track_io_timing, str):
            raise TypeError("Expected argument 'engine_config_pg_track_io_timing' to be a str")
        pulumi.set(__self__, "engine_config_pg_track_io_timing", engine_config_pg_track_io_timing)
        if engine_config_pg_wal_sender_timeout and not isinstance(engine_config_pg_wal_sender_timeout, int):
            raise TypeError("Expected argument 'engine_config_pg_wal_sender_timeout' to be a int")
        pulumi.set(__self__, "engine_config_pg_wal_sender_timeout", engine_config_pg_wal_sender_timeout)
        if engine_config_pg_wal_writer_delay and not isinstance(engine_config_pg_wal_writer_delay, int):
            raise TypeError("Expected argument 'engine_config_pg_wal_writer_delay' to be a int")
        pulumi.set(__self__, "engine_config_pg_wal_writer_delay", engine_config_pg_wal_writer_delay)
        if engine_config_pglookout_max_failover_replication_time_lag and not isinstance(engine_config_pglookout_max_failover_replication_time_lag, int):
            raise TypeError("Expected argument 'engine_config_pglookout_max_failover_replication_time_lag' to be a int")
        pulumi.set(__self__, "engine_config_pglookout_max_failover_replication_time_lag", engine_config_pglookout_max_failover_replication_time_lag)
        if engine_config_shared_buffers_percentage and not isinstance(engine_config_shared_buffers_percentage, float):
            raise TypeError("Expected argument 'engine_config_shared_buffers_percentage' to be a float")
        pulumi.set(__self__, "engine_config_shared_buffers_percentage", engine_config_shared_buffers_percentage)
        if engine_config_work_mem and not isinstance(engine_config_work_mem, int):
            raise TypeError("Expected argument 'engine_config_work_mem' to be a int")
        pulumi.set(__self__, "engine_config_work_mem", engine_config_work_mem)
        if engine_id and not isinstance(engine_id, str):
            raise TypeError("Expected argument 'engine_id' to be a str")
        pulumi.set(__self__, "engine_id", engine_id)
        if fork_restore_time and not isinstance(fork_restore_time, str):
            raise TypeError("Expected argument 'fork_restore_time' to be a str")
        pulumi.set(__self__, "fork_restore_time", fork_restore_time)
        if fork_source and not isinstance(fork_source, int):
            raise TypeError("Expected argument 'fork_source' to be a int")
        pulumi.set(__self__, "fork_source", fork_source)
        if host_primary and not isinstance(host_primary, str):
            raise TypeError("Expected argument 'host_primary' to be a str")
        pulumi.set(__self__, "host_primary", host_primary)
        if host_secondary and not isinstance(host_secondary, str):
            raise TypeError("Expected argument 'host_secondary' to be a str")
        pulumi.set(__self__, "host_secondary", host_secondary)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if members and not isinstance(members, dict):
            raise TypeError("Expected argument 'members' to be a dict")
        pulumi.set(__self__, "members", members)
        if oldest_restore_time and not isinstance(oldest_restore_time, str):
            raise TypeError("Expected argument 'oldest_restore_time' to be a str")
        pulumi.set(__self__, "oldest_restore_time", oldest_restore_time)
        if pending_updates and not isinstance(pending_updates, list):
            raise TypeError("Expected argument 'pending_updates' to be a list")
        pulumi.set(__self__, "pending_updates", pending_updates)
        if platform and not isinstance(platform, str):
            raise TypeError("Expected argument 'platform' to be a str")
        pulumi.set(__self__, "platform", platform)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if private_network and not isinstance(private_network, dict):
            raise TypeError("Expected argument 'private_network' to be a dict")
        pulumi.set(__self__, "private_network", private_network)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if root_password and not isinstance(root_password, str):
            raise TypeError("Expected argument 'root_password' to be a str")
        pulumi.set(__self__, "root_password", root_password)
        if root_username and not isinstance(root_username, str):
            raise TypeError("Expected argument 'root_username' to be a str")
        pulumi.set(__self__, "root_username", root_username)
        if ssl_connection and not isinstance(ssl_connection, bool):
            raise TypeError("Expected argument 'ssl_connection' to be a bool")
        pulumi.set(__self__, "ssl_connection", ssl_connection)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if suspended and not isinstance(suspended, bool):
            raise TypeError("Expected argument 'suspended' to be a bool")
        pulumi.set(__self__, "suspended", suspended)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if updated and not isinstance(updated, str):
            raise TypeError("Expected argument 'updated' to be a str")
        pulumi.set(__self__, "updated", updated)
        if updates and not isinstance(updates, dict):
            raise TypeError("Expected argument 'updates' to be a dict")
        pulumi.set(__self__, "updates", updates)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> Sequence[_builtins.str]:
        """
        A list of IP addresses that can access the Managed Database. Each item can be a single IP address or a range in CIDR format. Use `DatabaseAccessControls` to manage your allow list separately.
        """
        return pulumi.get(self, "allow_lists")

    @_builtins.property
    @pulumi.getter(name="caCert")
    def ca_cert(self) -> _builtins.str:
        """
        The base64-encoded SSL CA certificate for the Managed Database.
        """
        return pulumi.get(self, "ca_cert")

    @_builtins.property
    @pulumi.getter(name="clusterSize")
    def cluster_size(self) -> _builtins.int:
        """
        The number of Linode Instance nodes deployed to the Managed Database. (default `1`)
        """
        return pulumi.get(self, "cluster_size")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        When this Managed Database was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def encrypted(self) -> _builtins.bool:
        """
        Whether the Managed Databases is encrypted.
        """
        return pulumi.get(self, "encrypted")

    @_builtins.property
    @pulumi.getter
    def engine(self) -> _builtins.str:
        """
        The Managed Database engine. (e.g. `postgresql`)
        """
        return pulumi.get(self, "engine")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgAutovacuumAnalyzeScaleFactor")
    def engine_config_pg_autovacuum_analyze_scale_factor(self) -> _builtins.float:
        """
        Specifies a fraction of the table size to add to autovacuum_analyze_threshold when deciding whether to trigger an ANALYZE. The default is 0.2 (20% of table size)
        """
        return pulumi.get(self, "engine_config_pg_autovacuum_analyze_scale_factor")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgAutovacuumAnalyzeThreshold")
    def engine_config_pg_autovacuum_analyze_threshold(self) -> _builtins.int:
        """
        Specifies the minimum number of inserted, updated or deleted tuples needed to trigger an ANALYZE in any one table. The default is 50 tuples.
        """
        return pulumi.get(self, "engine_config_pg_autovacuum_analyze_threshold")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgAutovacuumMaxWorkers")
    def engine_config_pg_autovacuum_max_workers(self) -> _builtins.int:
        """
        Specifies the maximum number of autovacuum processes (other than the autovacuum launcher) that may be running at any one time. The default is three. This parameter can only be set at server start.
        """
        return pulumi.get(self, "engine_config_pg_autovacuum_max_workers")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgAutovacuumNaptime")
    def engine_config_pg_autovacuum_naptime(self) -> _builtins.int:
        """
        Specifies the minimum delay between autovacuum runs on any given database. The delay is measured in seconds, and the default is one minute
        """
        return pulumi.get(self, "engine_config_pg_autovacuum_naptime")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgAutovacuumVacuumCostDelay")
    def engine_config_pg_autovacuum_vacuum_cost_delay(self) -> _builtins.int:
        """
        Specifies the cost delay value that will be used in automatic VACUUM operations. If -1 is specified, the regular vacuum_cost_delay value will be used. The default value is 20 milliseconds
        """
        return pulumi.get(self, "engine_config_pg_autovacuum_vacuum_cost_delay")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgAutovacuumVacuumCostLimit")
    def engine_config_pg_autovacuum_vacuum_cost_limit(self) -> _builtins.int:
        """
        Specifies the cost limit value that will be used in automatic VACUUM operations. If -1 is specified (which is the default), the regular vacuum_cost_limit value will be used.
        """
        return pulumi.get(self, "engine_config_pg_autovacuum_vacuum_cost_limit")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgAutovacuumVacuumScaleFactor")
    def engine_config_pg_autovacuum_vacuum_scale_factor(self) -> _builtins.float:
        """
        Specifies a fraction of the table size to add to autovacuum_vacuum_threshold when deciding whether to trigger a VACUUM. The default is 0.2 (20% of table size)
        """
        return pulumi.get(self, "engine_config_pg_autovacuum_vacuum_scale_factor")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgAutovacuumVacuumThreshold")
    def engine_config_pg_autovacuum_vacuum_threshold(self) -> _builtins.int:
        """
        Specifies the minimum number of updated or deleted tuples needed to trigger a VACUUM in any one table. The default is 50 tuples.
        """
        return pulumi.get(self, "engine_config_pg_autovacuum_vacuum_threshold")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgBgwriterDelay")
    def engine_config_pg_bgwriter_delay(self) -> _builtins.int:
        """
        Specifies the delay between activity rounds for the background writer in milliseconds. Default is 200.
        """
        return pulumi.get(self, "engine_config_pg_bgwriter_delay")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgBgwriterFlushAfter")
    def engine_config_pg_bgwriter_flush_after(self) -> _builtins.int:
        """
        Whenever more than bgwriter_flush_after bytes have been written by the background writer, attempt to force the OS to issue these writes to the underlying storage. Specified in kilobytes, default is 512. Setting of 0 disables forced writeback.
        """
        return pulumi.get(self, "engine_config_pg_bgwriter_flush_after")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgBgwriterLruMaxpages")
    def engine_config_pg_bgwriter_lru_maxpages(self) -> _builtins.int:
        """
        In each round, no more than this many buffers will be written by the background writer. Setting this to zero disables background writing. Default is 100.
        """
        return pulumi.get(self, "engine_config_pg_bgwriter_lru_maxpages")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgBgwriterLruMultiplier")
    def engine_config_pg_bgwriter_lru_multiplier(self) -> _builtins.float:
        """
        The average recent need for new buffers is multiplied by bgwriter_lru_multiplier to arrive at an estimate of the number that will be needed during the next round, (up to bgwriter_lru_maxpages). 1.0 represents a “just in time” policy of writing exactly the number of buffers predicted to be needed. Larger values provide some cushion against spikes in demand, while smaller values intentionally leave writes to be done by server processes. The default is 2.0.
        """
        return pulumi.get(self, "engine_config_pg_bgwriter_lru_multiplier")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgDeadlockTimeout")
    def engine_config_pg_deadlock_timeout(self) -> _builtins.int:
        """
        This is the amount of time, in milliseconds, to wait on a lock before checking to see if there is a deadlock condition.
        """
        return pulumi.get(self, "engine_config_pg_deadlock_timeout")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgDefaultToastCompression")
    def engine_config_pg_default_toast_compression(self) -> _builtins.str:
        """
        Specifies the default TOAST compression method for values of compressible columns (the default is lz4).
        """
        return pulumi.get(self, "engine_config_pg_default_toast_compression")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgIdleInTransactionSessionTimeout")
    def engine_config_pg_idle_in_transaction_session_timeout(self) -> _builtins.int:
        """
        Time out sessions with open transactions after this number of milliseconds.
        """
        return pulumi.get(self, "engine_config_pg_idle_in_transaction_session_timeout")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgJit")
    def engine_config_pg_jit(self) -> _builtins.bool:
        """
        Controls system-wide use of Just-in-Time Compilation (JIT).
        """
        return pulumi.get(self, "engine_config_pg_jit")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxFilesPerProcess")
    def engine_config_pg_max_files_per_process(self) -> _builtins.int:
        """
        PostgreSQL maximum number of files that can be open per process.
        """
        return pulumi.get(self, "engine_config_pg_max_files_per_process")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxLocksPerTransaction")
    def engine_config_pg_max_locks_per_transaction(self) -> _builtins.int:
        """
        PostgreSQL maximum locks per transaction.
        """
        return pulumi.get(self, "engine_config_pg_max_locks_per_transaction")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxLogicalReplicationWorkers")
    def engine_config_pg_max_logical_replication_workers(self) -> _builtins.int:
        """
        PostgreSQL maximum logical replication workers (taken from the pool of max_parallel_workers).
        """
        return pulumi.get(self, "engine_config_pg_max_logical_replication_workers")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxParallelWorkers")
    def engine_config_pg_max_parallel_workers(self) -> _builtins.int:
        """
        Sets the maximum number of workers that the system can support for parallel queries.
        """
        return pulumi.get(self, "engine_config_pg_max_parallel_workers")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxParallelWorkersPerGather")
    def engine_config_pg_max_parallel_workers_per_gather(self) -> _builtins.int:
        """
        Sets the maximum number of workers that can be started by a single Gather or Gather Merge node.
        """
        return pulumi.get(self, "engine_config_pg_max_parallel_workers_per_gather")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxPredLocksPerTransaction")
    def engine_config_pg_max_pred_locks_per_transaction(self) -> _builtins.int:
        """
        PostgreSQL maximum predicate locks per transaction.
        """
        return pulumi.get(self, "engine_config_pg_max_pred_locks_per_transaction")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxReplicationSlots")
    def engine_config_pg_max_replication_slots(self) -> _builtins.int:
        """
        PostgreSQL maximum replication slots.
        """
        return pulumi.get(self, "engine_config_pg_max_replication_slots")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxSlotWalKeepSize")
    def engine_config_pg_max_slot_wal_keep_size(self) -> _builtins.int:
        """
        PostgreSQL maximum WAL size (MB) reserved for replication slots. Default is -1 (unlimited). wal_keep_size minimum WAL size setting takes precedence over this.
        """
        return pulumi.get(self, "engine_config_pg_max_slot_wal_keep_size")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxStackDepth")
    def engine_config_pg_max_stack_depth(self) -> _builtins.int:
        """
        Maximum depth of the stack in bytes.
        """
        return pulumi.get(self, "engine_config_pg_max_stack_depth")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxStandbyArchiveDelay")
    def engine_config_pg_max_standby_archive_delay(self) -> _builtins.int:
        """
        Max standby archive delay in milliseconds.
        """
        return pulumi.get(self, "engine_config_pg_max_standby_archive_delay")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxStandbyStreamingDelay")
    def engine_config_pg_max_standby_streaming_delay(self) -> _builtins.int:
        """
        Max standby streaming delay in milliseconds.
        """
        return pulumi.get(self, "engine_config_pg_max_standby_streaming_delay")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxWalSenders")
    def engine_config_pg_max_wal_senders(self) -> _builtins.int:
        """
        PostgreSQL maximum WAL senders.
        """
        return pulumi.get(self, "engine_config_pg_max_wal_senders")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgMaxWorkerProcesses")
    def engine_config_pg_max_worker_processes(self) -> _builtins.int:
        """
        Sets the maximum number of background processes that the system can support.
        """
        return pulumi.get(self, "engine_config_pg_max_worker_processes")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgPasswordEncryption")
    def engine_config_pg_password_encryption(self) -> _builtins.str:
        """
        Chooses the algorithm for encrypting passwords.
        """
        return pulumi.get(self, "engine_config_pg_password_encryption")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgPgPartmanBgwInterval")
    def engine_config_pg_pg_partman_bgw_interval(self) -> _builtins.int:
        """
        Sets the time interval to run pg_partman's scheduled tasks.
        """
        return pulumi.get(self, "engine_config_pg_pg_partman_bgw_interval")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgPgPartmanBgwRole")
    def engine_config_pg_pg_partman_bgw_role(self) -> _builtins.str:
        """
        Controls which role to use for pg_partman's scheduled background tasks.
        """
        return pulumi.get(self, "engine_config_pg_pg_partman_bgw_role")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgPgStatMonitorPgsmEnableQueryPlan")
    def engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan(self) -> _builtins.bool:
        """
        Enables or disables query plan monitoring.
        """
        return pulumi.get(self, "engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgPgStatMonitorPgsmMaxBuckets")
    def engine_config_pg_pg_stat_monitor_pgsm_max_buckets(self) -> _builtins.int:
        """
        Sets the maximum number of buckets.
        """
        return pulumi.get(self, "engine_config_pg_pg_stat_monitor_pgsm_max_buckets")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgPgStatStatementsTrack")
    def engine_config_pg_pg_stat_statements_track(self) -> _builtins.str:
        """
        Controls which statements are counted. Specify top to track top-level statements (those issued directly by clients), all to also track nested statements (such as statements invoked within functions), or none to disable statement statistics collection. The default value is top.
        """
        return pulumi.get(self, "engine_config_pg_pg_stat_statements_track")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgStatMonitorEnable")
    def engine_config_pg_stat_monitor_enable(self) -> _builtins.bool:
        """
        Enable the pg_stat_monitor extension. Enabling this extension will cause the cluster to be restarted. When this extension is enabled, pg_stat_statements results for utility commands are unreliable.
        """
        return pulumi.get(self, "engine_config_pg_stat_monitor_enable")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgTempFileLimit")
    def engine_config_pg_temp_file_limit(self) -> _builtins.int:
        """
        PostgreSQL temporary file limit in KiB, -1 for unlimited.
        """
        return pulumi.get(self, "engine_config_pg_temp_file_limit")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgTimezone")
    def engine_config_pg_timezone(self) -> _builtins.str:
        """
        PostgreSQL service timezone.
        """
        return pulumi.get(self, "engine_config_pg_timezone")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgTrackActivityQuerySize")
    def engine_config_pg_track_activity_query_size(self) -> _builtins.int:
        """
        Specifies the number of bytes reserved to track the currently executing command for each active session.
        """
        return pulumi.get(self, "engine_config_pg_track_activity_query_size")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgTrackCommitTimestamp")
    def engine_config_pg_track_commit_timestamp(self) -> _builtins.str:
        """
        Record commit time of transactions.
        """
        return pulumi.get(self, "engine_config_pg_track_commit_timestamp")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgTrackFunctions")
    def engine_config_pg_track_functions(self) -> _builtins.str:
        """
        Enables tracking of function call counts and time used.
        """
        return pulumi.get(self, "engine_config_pg_track_functions")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgTrackIoTiming")
    def engine_config_pg_track_io_timing(self) -> _builtins.str:
        """
        Enables timing of database I/O calls. This parameter is off by default, because it will repeatedly query the operating system for the current time, which may cause significant overhead on some platforms.
        """
        return pulumi.get(self, "engine_config_pg_track_io_timing")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgWalSenderTimeout")
    def engine_config_pg_wal_sender_timeout(self) -> _builtins.int:
        """
        Terminate replication connections that are inactive for longer than this amount of time, in milliseconds. Setting this value to zero disables the timeout.
        """
        return pulumi.get(self, "engine_config_pg_wal_sender_timeout")

    @_builtins.property
    @pulumi.getter(name="engineConfigPgWalWriterDelay")
    def engine_config_pg_wal_writer_delay(self) -> _builtins.int:
        """
        WAL flush interval in milliseconds. Note that setting this value to lower than the default 200ms may negatively impact performance.
        """
        return pulumi.get(self, "engine_config_pg_wal_writer_delay")

    @_builtins.property
    @pulumi.getter(name="engineConfigPglookoutMaxFailoverReplicationTimeLag")
    def engine_config_pglookout_max_failover_replication_time_lag(self) -> _builtins.int:
        """
        Number of seconds of master unavailability before triggering database failover to standby.
        """
        return pulumi.get(self, "engine_config_pglookout_max_failover_replication_time_lag")

    @_builtins.property
    @pulumi.getter(name="engineConfigSharedBuffersPercentage")
    def engine_config_shared_buffers_percentage(self) -> _builtins.float:
        """
        Percentage of total RAM that the database server uses for shared memory buffers. Valid range is 20-60 (float), which corresponds to 20% - 60%. This setting adjusts the shared_buffers configuration value.
        """
        return pulumi.get(self, "engine_config_shared_buffers_percentage")

    @_builtins.property
    @pulumi.getter(name="engineConfigWorkMem")
    def engine_config_work_mem(self) -> _builtins.int:
        """
        Sets the maximum amount of memory to be used by a query operation (such as a sort or hash table) before writing to temporary disk files, in MB. Default is 1MB + 0.075% of total RAM (up to 32MB).
        """
        return pulumi.get(self, "engine_config_work_mem")

    @_builtins.property
    @pulumi.getter(name="engineId")
    def engine_id(self) -> _builtins.str:
        """
        The Managed Database engine in engine/version format. (e.g. `postgresql/16`)
        """
        return pulumi.get(self, "engine_id")

    @_builtins.property
    @pulumi.getter(name="forkRestoreTime")
    def fork_restore_time(self) -> _builtins.str:
        """
        The database timestamp from which it was restored.
        """
        return pulumi.get(self, "fork_restore_time")

    @_builtins.property
    @pulumi.getter(name="forkSource")
    def fork_source(self) -> _builtins.int:
        """
        The ID of the database that was forked from.
        """
        return pulumi.get(self, "fork_source")

    @_builtins.property
    @pulumi.getter(name="hostPrimary")
    def host_primary(self) -> _builtins.str:
        """
        The primary host for the Managed Database.
        """
        return pulumi.get(self, "host_primary")

    @_builtins.property
    @pulumi.getter(name="hostSecondary")
    def host_secondary(self) -> _builtins.str:
        """
        The secondary/private host for the managed database.
        """
        return pulumi.get(self, "host_secondary")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def label(self) -> _builtins.str:
        """
        A unique, user-defined string referring to the Managed Database.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter
    def members(self) -> Mapping[str, _builtins.str]:
        return pulumi.get(self, "members")

    @_builtins.property
    @pulumi.getter(name="oldestRestoreTime")
    def oldest_restore_time(self) -> _builtins.str:
        return pulumi.get(self, "oldest_restore_time")

    @_builtins.property
    @pulumi.getter(name="pendingUpdates")
    def pending_updates(self) -> Sequence['outputs.GetDatabasePostgresqlV2PendingUpdateResult']:
        return pulumi.get(self, "pending_updates")

    @_builtins.property
    @pulumi.getter
    def platform(self) -> _builtins.str:
        """
        The back-end platform for relational databases used by the service.
        """
        return pulumi.get(self, "platform")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        The access port for this Managed Database.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> 'outputs.GetDatabasePostgresqlV2PrivateNetworkResult':
        return pulumi.get(self, "private_network")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The region to use for the Managed Database.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="rootPassword")
    def root_password(self) -> _builtins.str:
        """
        The randomly-generated root password for the Managed Database instance.
        """
        return pulumi.get(self, "root_password")

    @_builtins.property
    @pulumi.getter(name="rootUsername")
    def root_username(self) -> _builtins.str:
        """
        The root username for the Managed Database instance.
        """
        return pulumi.get(self, "root_username")

    @_builtins.property
    @pulumi.getter(name="sslConnection")
    def ssl_connection(self) -> _builtins.bool:
        """
        Whether to require SSL credentials to establish a connection to the Managed Database.
        """
        return pulumi.get(self, "ssl_connection")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The operating status of the Managed Database.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def suspended(self) -> _builtins.bool:
        """
        Whether this Managed Database is suspended.
        """
        return pulumi.get(self, "suspended")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The Linode Instance type used for the nodes of the Managed Database.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def updated(self) -> _builtins.str:
        """
        When this Managed Database was last updated.
        """
        return pulumi.get(self, "updated")

    @_builtins.property
    @pulumi.getter
    def updates(self) -> 'outputs.GetDatabasePostgresqlV2UpdatesResult':
        return pulumi.get(self, "updates")

    @_builtins.property
    @pulumi.getter
    def version(self) -> _builtins.str:
        """
        The Managed Database engine version. (e.g. `13.2`)
        """
        return pulumi.get(self, "version")


class AwaitableGetDatabasePostgresqlV2Result(GetDatabasePostgresqlV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabasePostgresqlV2Result(
            allow_lists=self.allow_lists,
            ca_cert=self.ca_cert,
            cluster_size=self.cluster_size,
            created=self.created,
            encrypted=self.encrypted,
            engine=self.engine,
            engine_config_pg_autovacuum_analyze_scale_factor=self.engine_config_pg_autovacuum_analyze_scale_factor,
            engine_config_pg_autovacuum_analyze_threshold=self.engine_config_pg_autovacuum_analyze_threshold,
            engine_config_pg_autovacuum_max_workers=self.engine_config_pg_autovacuum_max_workers,
            engine_config_pg_autovacuum_naptime=self.engine_config_pg_autovacuum_naptime,
            engine_config_pg_autovacuum_vacuum_cost_delay=self.engine_config_pg_autovacuum_vacuum_cost_delay,
            engine_config_pg_autovacuum_vacuum_cost_limit=self.engine_config_pg_autovacuum_vacuum_cost_limit,
            engine_config_pg_autovacuum_vacuum_scale_factor=self.engine_config_pg_autovacuum_vacuum_scale_factor,
            engine_config_pg_autovacuum_vacuum_threshold=self.engine_config_pg_autovacuum_vacuum_threshold,
            engine_config_pg_bgwriter_delay=self.engine_config_pg_bgwriter_delay,
            engine_config_pg_bgwriter_flush_after=self.engine_config_pg_bgwriter_flush_after,
            engine_config_pg_bgwriter_lru_maxpages=self.engine_config_pg_bgwriter_lru_maxpages,
            engine_config_pg_bgwriter_lru_multiplier=self.engine_config_pg_bgwriter_lru_multiplier,
            engine_config_pg_deadlock_timeout=self.engine_config_pg_deadlock_timeout,
            engine_config_pg_default_toast_compression=self.engine_config_pg_default_toast_compression,
            engine_config_pg_idle_in_transaction_session_timeout=self.engine_config_pg_idle_in_transaction_session_timeout,
            engine_config_pg_jit=self.engine_config_pg_jit,
            engine_config_pg_max_files_per_process=self.engine_config_pg_max_files_per_process,
            engine_config_pg_max_locks_per_transaction=self.engine_config_pg_max_locks_per_transaction,
            engine_config_pg_max_logical_replication_workers=self.engine_config_pg_max_logical_replication_workers,
            engine_config_pg_max_parallel_workers=self.engine_config_pg_max_parallel_workers,
            engine_config_pg_max_parallel_workers_per_gather=self.engine_config_pg_max_parallel_workers_per_gather,
            engine_config_pg_max_pred_locks_per_transaction=self.engine_config_pg_max_pred_locks_per_transaction,
            engine_config_pg_max_replication_slots=self.engine_config_pg_max_replication_slots,
            engine_config_pg_max_slot_wal_keep_size=self.engine_config_pg_max_slot_wal_keep_size,
            engine_config_pg_max_stack_depth=self.engine_config_pg_max_stack_depth,
            engine_config_pg_max_standby_archive_delay=self.engine_config_pg_max_standby_archive_delay,
            engine_config_pg_max_standby_streaming_delay=self.engine_config_pg_max_standby_streaming_delay,
            engine_config_pg_max_wal_senders=self.engine_config_pg_max_wal_senders,
            engine_config_pg_max_worker_processes=self.engine_config_pg_max_worker_processes,
            engine_config_pg_password_encryption=self.engine_config_pg_password_encryption,
            engine_config_pg_pg_partman_bgw_interval=self.engine_config_pg_pg_partman_bgw_interval,
            engine_config_pg_pg_partman_bgw_role=self.engine_config_pg_pg_partman_bgw_role,
            engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan=self.engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan,
            engine_config_pg_pg_stat_monitor_pgsm_max_buckets=self.engine_config_pg_pg_stat_monitor_pgsm_max_buckets,
            engine_config_pg_pg_stat_statements_track=self.engine_config_pg_pg_stat_statements_track,
            engine_config_pg_stat_monitor_enable=self.engine_config_pg_stat_monitor_enable,
            engine_config_pg_temp_file_limit=self.engine_config_pg_temp_file_limit,
            engine_config_pg_timezone=self.engine_config_pg_timezone,
            engine_config_pg_track_activity_query_size=self.engine_config_pg_track_activity_query_size,
            engine_config_pg_track_commit_timestamp=self.engine_config_pg_track_commit_timestamp,
            engine_config_pg_track_functions=self.engine_config_pg_track_functions,
            engine_config_pg_track_io_timing=self.engine_config_pg_track_io_timing,
            engine_config_pg_wal_sender_timeout=self.engine_config_pg_wal_sender_timeout,
            engine_config_pg_wal_writer_delay=self.engine_config_pg_wal_writer_delay,
            engine_config_pglookout_max_failover_replication_time_lag=self.engine_config_pglookout_max_failover_replication_time_lag,
            engine_config_shared_buffers_percentage=self.engine_config_shared_buffers_percentage,
            engine_config_work_mem=self.engine_config_work_mem,
            engine_id=self.engine_id,
            fork_restore_time=self.fork_restore_time,
            fork_source=self.fork_source,
            host_primary=self.host_primary,
            host_secondary=self.host_secondary,
            id=self.id,
            label=self.label,
            members=self.members,
            oldest_restore_time=self.oldest_restore_time,
            pending_updates=self.pending_updates,
            platform=self.platform,
            port=self.port,
            private_network=self.private_network,
            region=self.region,
            root_password=self.root_password,
            root_username=self.root_username,
            ssl_connection=self.ssl_connection,
            status=self.status,
            suspended=self.suspended,
            type=self.type,
            updated=self.updated,
            updates=self.updates,
            version=self.version)


def get_database_postgresql_v2(id: Optional[_builtins.str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabasePostgresqlV2Result:
    """
    Provides information about a Linode PostgreSQL Database.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-databases-postgre-sql-instance-backups).

    ## Example Usage

    Get information about a PostgreSQL database:

    ```python
    import pulumi
    import pulumi_linode as linode

    my_db = linode.get_database_postgresql_v2(id="12345")
    ```

    ## pending_updates

    The following arguments are exposed by each entry in the `pending_updates` attribute:

    * `deadline` - The time when a mandatory update needs to be applied.

    * `description` - A description of the update.

    * `planned_for` - The date and time a maintenance update will be applied.

    ## updates

    The following arguments are supported in the `updates` specification block:

    * `day_of_week` - The day to perform maintenance. (`monday`, `tuesday`, ...)

    * `duration` - The maximum maintenance window time in hours. (`1`..`3`)

    * `frequency` - The frequency at which maintenance occurs. (`weekly`)

    * `hour_of_day` - The hour to begin maintenance based in UTC time. (`0`..`23`)

    ## private_network

    The following arguments are exposed by the `private_network` attribute:

    * `vpc_id` - The ID of the virtual private cloud (VPC) to restrict access to this database using.

    * `subnet_id` - The ID of the VPC subnet to restrict access to this database using.

    * `public_access` - If true, clients outside the VPC can connect to the database using a public IP address.


    :param _builtins.str id: The ID of the PostgreSQL database.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getDatabasePostgresqlV2:getDatabasePostgresqlV2', __args__, opts=opts, typ=GetDatabasePostgresqlV2Result).value

    return AwaitableGetDatabasePostgresqlV2Result(
        allow_lists=pulumi.get(__ret__, 'allow_lists'),
        ca_cert=pulumi.get(__ret__, 'ca_cert'),
        cluster_size=pulumi.get(__ret__, 'cluster_size'),
        created=pulumi.get(__ret__, 'created'),
        encrypted=pulumi.get(__ret__, 'encrypted'),
        engine=pulumi.get(__ret__, 'engine'),
        engine_config_pg_autovacuum_analyze_scale_factor=pulumi.get(__ret__, 'engine_config_pg_autovacuum_analyze_scale_factor'),
        engine_config_pg_autovacuum_analyze_threshold=pulumi.get(__ret__, 'engine_config_pg_autovacuum_analyze_threshold'),
        engine_config_pg_autovacuum_max_workers=pulumi.get(__ret__, 'engine_config_pg_autovacuum_max_workers'),
        engine_config_pg_autovacuum_naptime=pulumi.get(__ret__, 'engine_config_pg_autovacuum_naptime'),
        engine_config_pg_autovacuum_vacuum_cost_delay=pulumi.get(__ret__, 'engine_config_pg_autovacuum_vacuum_cost_delay'),
        engine_config_pg_autovacuum_vacuum_cost_limit=pulumi.get(__ret__, 'engine_config_pg_autovacuum_vacuum_cost_limit'),
        engine_config_pg_autovacuum_vacuum_scale_factor=pulumi.get(__ret__, 'engine_config_pg_autovacuum_vacuum_scale_factor'),
        engine_config_pg_autovacuum_vacuum_threshold=pulumi.get(__ret__, 'engine_config_pg_autovacuum_vacuum_threshold'),
        engine_config_pg_bgwriter_delay=pulumi.get(__ret__, 'engine_config_pg_bgwriter_delay'),
        engine_config_pg_bgwriter_flush_after=pulumi.get(__ret__, 'engine_config_pg_bgwriter_flush_after'),
        engine_config_pg_bgwriter_lru_maxpages=pulumi.get(__ret__, 'engine_config_pg_bgwriter_lru_maxpages'),
        engine_config_pg_bgwriter_lru_multiplier=pulumi.get(__ret__, 'engine_config_pg_bgwriter_lru_multiplier'),
        engine_config_pg_deadlock_timeout=pulumi.get(__ret__, 'engine_config_pg_deadlock_timeout'),
        engine_config_pg_default_toast_compression=pulumi.get(__ret__, 'engine_config_pg_default_toast_compression'),
        engine_config_pg_idle_in_transaction_session_timeout=pulumi.get(__ret__, 'engine_config_pg_idle_in_transaction_session_timeout'),
        engine_config_pg_jit=pulumi.get(__ret__, 'engine_config_pg_jit'),
        engine_config_pg_max_files_per_process=pulumi.get(__ret__, 'engine_config_pg_max_files_per_process'),
        engine_config_pg_max_locks_per_transaction=pulumi.get(__ret__, 'engine_config_pg_max_locks_per_transaction'),
        engine_config_pg_max_logical_replication_workers=pulumi.get(__ret__, 'engine_config_pg_max_logical_replication_workers'),
        engine_config_pg_max_parallel_workers=pulumi.get(__ret__, 'engine_config_pg_max_parallel_workers'),
        engine_config_pg_max_parallel_workers_per_gather=pulumi.get(__ret__, 'engine_config_pg_max_parallel_workers_per_gather'),
        engine_config_pg_max_pred_locks_per_transaction=pulumi.get(__ret__, 'engine_config_pg_max_pred_locks_per_transaction'),
        engine_config_pg_max_replication_slots=pulumi.get(__ret__, 'engine_config_pg_max_replication_slots'),
        engine_config_pg_max_slot_wal_keep_size=pulumi.get(__ret__, 'engine_config_pg_max_slot_wal_keep_size'),
        engine_config_pg_max_stack_depth=pulumi.get(__ret__, 'engine_config_pg_max_stack_depth'),
        engine_config_pg_max_standby_archive_delay=pulumi.get(__ret__, 'engine_config_pg_max_standby_archive_delay'),
        engine_config_pg_max_standby_streaming_delay=pulumi.get(__ret__, 'engine_config_pg_max_standby_streaming_delay'),
        engine_config_pg_max_wal_senders=pulumi.get(__ret__, 'engine_config_pg_max_wal_senders'),
        engine_config_pg_max_worker_processes=pulumi.get(__ret__, 'engine_config_pg_max_worker_processes'),
        engine_config_pg_password_encryption=pulumi.get(__ret__, 'engine_config_pg_password_encryption'),
        engine_config_pg_pg_partman_bgw_interval=pulumi.get(__ret__, 'engine_config_pg_pg_partman_bgw_interval'),
        engine_config_pg_pg_partman_bgw_role=pulumi.get(__ret__, 'engine_config_pg_pg_partman_bgw_role'),
        engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan=pulumi.get(__ret__, 'engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan'),
        engine_config_pg_pg_stat_monitor_pgsm_max_buckets=pulumi.get(__ret__, 'engine_config_pg_pg_stat_monitor_pgsm_max_buckets'),
        engine_config_pg_pg_stat_statements_track=pulumi.get(__ret__, 'engine_config_pg_pg_stat_statements_track'),
        engine_config_pg_stat_monitor_enable=pulumi.get(__ret__, 'engine_config_pg_stat_monitor_enable'),
        engine_config_pg_temp_file_limit=pulumi.get(__ret__, 'engine_config_pg_temp_file_limit'),
        engine_config_pg_timezone=pulumi.get(__ret__, 'engine_config_pg_timezone'),
        engine_config_pg_track_activity_query_size=pulumi.get(__ret__, 'engine_config_pg_track_activity_query_size'),
        engine_config_pg_track_commit_timestamp=pulumi.get(__ret__, 'engine_config_pg_track_commit_timestamp'),
        engine_config_pg_track_functions=pulumi.get(__ret__, 'engine_config_pg_track_functions'),
        engine_config_pg_track_io_timing=pulumi.get(__ret__, 'engine_config_pg_track_io_timing'),
        engine_config_pg_wal_sender_timeout=pulumi.get(__ret__, 'engine_config_pg_wal_sender_timeout'),
        engine_config_pg_wal_writer_delay=pulumi.get(__ret__, 'engine_config_pg_wal_writer_delay'),
        engine_config_pglookout_max_failover_replication_time_lag=pulumi.get(__ret__, 'engine_config_pglookout_max_failover_replication_time_lag'),
        engine_config_shared_buffers_percentage=pulumi.get(__ret__, 'engine_config_shared_buffers_percentage'),
        engine_config_work_mem=pulumi.get(__ret__, 'engine_config_work_mem'),
        engine_id=pulumi.get(__ret__, 'engine_id'),
        fork_restore_time=pulumi.get(__ret__, 'fork_restore_time'),
        fork_source=pulumi.get(__ret__, 'fork_source'),
        host_primary=pulumi.get(__ret__, 'host_primary'),
        host_secondary=pulumi.get(__ret__, 'host_secondary'),
        id=pulumi.get(__ret__, 'id'),
        label=pulumi.get(__ret__, 'label'),
        members=pulumi.get(__ret__, 'members'),
        oldest_restore_time=pulumi.get(__ret__, 'oldest_restore_time'),
        pending_updates=pulumi.get(__ret__, 'pending_updates'),
        platform=pulumi.get(__ret__, 'platform'),
        port=pulumi.get(__ret__, 'port'),
        private_network=pulumi.get(__ret__, 'private_network'),
        region=pulumi.get(__ret__, 'region'),
        root_password=pulumi.get(__ret__, 'root_password'),
        root_username=pulumi.get(__ret__, 'root_username'),
        ssl_connection=pulumi.get(__ret__, 'ssl_connection'),
        status=pulumi.get(__ret__, 'status'),
        suspended=pulumi.get(__ret__, 'suspended'),
        type=pulumi.get(__ret__, 'type'),
        updated=pulumi.get(__ret__, 'updated'),
        updates=pulumi.get(__ret__, 'updates'),
        version=pulumi.get(__ret__, 'version'))
def get_database_postgresql_v2_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabasePostgresqlV2Result]:
    """
    Provides information about a Linode PostgreSQL Database.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-databases-postgre-sql-instance-backups).

    ## Example Usage

    Get information about a PostgreSQL database:

    ```python
    import pulumi
    import pulumi_linode as linode

    my_db = linode.get_database_postgresql_v2(id="12345")
    ```

    ## pending_updates

    The following arguments are exposed by each entry in the `pending_updates` attribute:

    * `deadline` - The time when a mandatory update needs to be applied.

    * `description` - A description of the update.

    * `planned_for` - The date and time a maintenance update will be applied.

    ## updates

    The following arguments are supported in the `updates` specification block:

    * `day_of_week` - The day to perform maintenance. (`monday`, `tuesday`, ...)

    * `duration` - The maximum maintenance window time in hours. (`1`..`3`)

    * `frequency` - The frequency at which maintenance occurs. (`weekly`)

    * `hour_of_day` - The hour to begin maintenance based in UTC time. (`0`..`23`)

    ## private_network

    The following arguments are exposed by the `private_network` attribute:

    * `vpc_id` - The ID of the virtual private cloud (VPC) to restrict access to this database using.

    * `subnet_id` - The ID of the VPC subnet to restrict access to this database using.

    * `public_access` - If true, clients outside the VPC can connect to the database using a public IP address.


    :param _builtins.str id: The ID of the PostgreSQL database.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getDatabasePostgresqlV2:getDatabasePostgresqlV2', __args__, opts=opts, typ=GetDatabasePostgresqlV2Result)
    return __ret__.apply(lambda __response__: GetDatabasePostgresqlV2Result(
        allow_lists=pulumi.get(__response__, 'allow_lists'),
        ca_cert=pulumi.get(__response__, 'ca_cert'),
        cluster_size=pulumi.get(__response__, 'cluster_size'),
        created=pulumi.get(__response__, 'created'),
        encrypted=pulumi.get(__response__, 'encrypted'),
        engine=pulumi.get(__response__, 'engine'),
        engine_config_pg_autovacuum_analyze_scale_factor=pulumi.get(__response__, 'engine_config_pg_autovacuum_analyze_scale_factor'),
        engine_config_pg_autovacuum_analyze_threshold=pulumi.get(__response__, 'engine_config_pg_autovacuum_analyze_threshold'),
        engine_config_pg_autovacuum_max_workers=pulumi.get(__response__, 'engine_config_pg_autovacuum_max_workers'),
        engine_config_pg_autovacuum_naptime=pulumi.get(__response__, 'engine_config_pg_autovacuum_naptime'),
        engine_config_pg_autovacuum_vacuum_cost_delay=pulumi.get(__response__, 'engine_config_pg_autovacuum_vacuum_cost_delay'),
        engine_config_pg_autovacuum_vacuum_cost_limit=pulumi.get(__response__, 'engine_config_pg_autovacuum_vacuum_cost_limit'),
        engine_config_pg_autovacuum_vacuum_scale_factor=pulumi.get(__response__, 'engine_config_pg_autovacuum_vacuum_scale_factor'),
        engine_config_pg_autovacuum_vacuum_threshold=pulumi.get(__response__, 'engine_config_pg_autovacuum_vacuum_threshold'),
        engine_config_pg_bgwriter_delay=pulumi.get(__response__, 'engine_config_pg_bgwriter_delay'),
        engine_config_pg_bgwriter_flush_after=pulumi.get(__response__, 'engine_config_pg_bgwriter_flush_after'),
        engine_config_pg_bgwriter_lru_maxpages=pulumi.get(__response__, 'engine_config_pg_bgwriter_lru_maxpages'),
        engine_config_pg_bgwriter_lru_multiplier=pulumi.get(__response__, 'engine_config_pg_bgwriter_lru_multiplier'),
        engine_config_pg_deadlock_timeout=pulumi.get(__response__, 'engine_config_pg_deadlock_timeout'),
        engine_config_pg_default_toast_compression=pulumi.get(__response__, 'engine_config_pg_default_toast_compression'),
        engine_config_pg_idle_in_transaction_session_timeout=pulumi.get(__response__, 'engine_config_pg_idle_in_transaction_session_timeout'),
        engine_config_pg_jit=pulumi.get(__response__, 'engine_config_pg_jit'),
        engine_config_pg_max_files_per_process=pulumi.get(__response__, 'engine_config_pg_max_files_per_process'),
        engine_config_pg_max_locks_per_transaction=pulumi.get(__response__, 'engine_config_pg_max_locks_per_transaction'),
        engine_config_pg_max_logical_replication_workers=pulumi.get(__response__, 'engine_config_pg_max_logical_replication_workers'),
        engine_config_pg_max_parallel_workers=pulumi.get(__response__, 'engine_config_pg_max_parallel_workers'),
        engine_config_pg_max_parallel_workers_per_gather=pulumi.get(__response__, 'engine_config_pg_max_parallel_workers_per_gather'),
        engine_config_pg_max_pred_locks_per_transaction=pulumi.get(__response__, 'engine_config_pg_max_pred_locks_per_transaction'),
        engine_config_pg_max_replication_slots=pulumi.get(__response__, 'engine_config_pg_max_replication_slots'),
        engine_config_pg_max_slot_wal_keep_size=pulumi.get(__response__, 'engine_config_pg_max_slot_wal_keep_size'),
        engine_config_pg_max_stack_depth=pulumi.get(__response__, 'engine_config_pg_max_stack_depth'),
        engine_config_pg_max_standby_archive_delay=pulumi.get(__response__, 'engine_config_pg_max_standby_archive_delay'),
        engine_config_pg_max_standby_streaming_delay=pulumi.get(__response__, 'engine_config_pg_max_standby_streaming_delay'),
        engine_config_pg_max_wal_senders=pulumi.get(__response__, 'engine_config_pg_max_wal_senders'),
        engine_config_pg_max_worker_processes=pulumi.get(__response__, 'engine_config_pg_max_worker_processes'),
        engine_config_pg_password_encryption=pulumi.get(__response__, 'engine_config_pg_password_encryption'),
        engine_config_pg_pg_partman_bgw_interval=pulumi.get(__response__, 'engine_config_pg_pg_partman_bgw_interval'),
        engine_config_pg_pg_partman_bgw_role=pulumi.get(__response__, 'engine_config_pg_pg_partman_bgw_role'),
        engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan=pulumi.get(__response__, 'engine_config_pg_pg_stat_monitor_pgsm_enable_query_plan'),
        engine_config_pg_pg_stat_monitor_pgsm_max_buckets=pulumi.get(__response__, 'engine_config_pg_pg_stat_monitor_pgsm_max_buckets'),
        engine_config_pg_pg_stat_statements_track=pulumi.get(__response__, 'engine_config_pg_pg_stat_statements_track'),
        engine_config_pg_stat_monitor_enable=pulumi.get(__response__, 'engine_config_pg_stat_monitor_enable'),
        engine_config_pg_temp_file_limit=pulumi.get(__response__, 'engine_config_pg_temp_file_limit'),
        engine_config_pg_timezone=pulumi.get(__response__, 'engine_config_pg_timezone'),
        engine_config_pg_track_activity_query_size=pulumi.get(__response__, 'engine_config_pg_track_activity_query_size'),
        engine_config_pg_track_commit_timestamp=pulumi.get(__response__, 'engine_config_pg_track_commit_timestamp'),
        engine_config_pg_track_functions=pulumi.get(__response__, 'engine_config_pg_track_functions'),
        engine_config_pg_track_io_timing=pulumi.get(__response__, 'engine_config_pg_track_io_timing'),
        engine_config_pg_wal_sender_timeout=pulumi.get(__response__, 'engine_config_pg_wal_sender_timeout'),
        engine_config_pg_wal_writer_delay=pulumi.get(__response__, 'engine_config_pg_wal_writer_delay'),
        engine_config_pglookout_max_failover_replication_time_lag=pulumi.get(__response__, 'engine_config_pglookout_max_failover_replication_time_lag'),
        engine_config_shared_buffers_percentage=pulumi.get(__response__, 'engine_config_shared_buffers_percentage'),
        engine_config_work_mem=pulumi.get(__response__, 'engine_config_work_mem'),
        engine_id=pulumi.get(__response__, 'engine_id'),
        fork_restore_time=pulumi.get(__response__, 'fork_restore_time'),
        fork_source=pulumi.get(__response__, 'fork_source'),
        host_primary=pulumi.get(__response__, 'host_primary'),
        host_secondary=pulumi.get(__response__, 'host_secondary'),
        id=pulumi.get(__response__, 'id'),
        label=pulumi.get(__response__, 'label'),
        members=pulumi.get(__response__, 'members'),
        oldest_restore_time=pulumi.get(__response__, 'oldest_restore_time'),
        pending_updates=pulumi.get(__response__, 'pending_updates'),
        platform=pulumi.get(__response__, 'platform'),
        port=pulumi.get(__response__, 'port'),
        private_network=pulumi.get(__response__, 'private_network'),
        region=pulumi.get(__response__, 'region'),
        root_password=pulumi.get(__response__, 'root_password'),
        root_username=pulumi.get(__response__, 'root_username'),
        ssl_connection=pulumi.get(__response__, 'ssl_connection'),
        status=pulumi.get(__response__, 'status'),
        suspended=pulumi.get(__response__, 'suspended'),
        type=pulumi.get(__response__, 'type'),
        updated=pulumi.get(__response__, 'updated'),
        updates=pulumi.get(__response__, 'updates'),
        version=pulumi.get(__response__, 'version')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetLkeClustersResult',
    'AwaitableGetLkeClustersResult',
    'get_lke_clusters',
    'get_lke_clusters_output',
]

@pulumi.output_type
class GetLkeClustersResult:
    """
    A collection of values returned by getLkeClusters.
    """
    def __init__(__self__, filters=None, id=None, lke_clusters=None, order=None, order_by=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lke_clusters and not isinstance(lke_clusters, list):
            raise TypeError("Expected argument 'lke_clusters' to be a list")
        pulumi.set(__self__, "lke_clusters", lke_clusters)
        if order and not isinstance(order, str):
            raise TypeError("Expected argument 'order' to be a str")
        pulumi.set(__self__, "order", order)
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        pulumi.set(__self__, "order_by", order_by)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetLkeClustersFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The LKE Cluster's ID.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lkeClusters")
    def lke_clusters(self) -> Optional[Sequence['outputs.GetLkeClustersLkeClusterResult']]:
        return pulumi.get(self, "lke_clusters")

    @_builtins.property
    @pulumi.getter
    def order(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order")

    @_builtins.property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order_by")


class AwaitableGetLkeClustersResult(GetLkeClustersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLkeClustersResult(
            filters=self.filters,
            id=self.id,
            lke_clusters=self.lke_clusters,
            order=self.order,
            order_by=self.order_by)


def get_lke_clusters(filters: Optional[Sequence[Union['GetLkeClustersFilterArgs', 'GetLkeClustersFilterArgsDict']]] = None,
                     lke_clusters: Optional[Sequence[Union['GetLkeClustersLkeClusterArgs', 'GetLkeClustersLkeClusterArgsDict']]] = None,
                     order: Optional[_builtins.str] = None,
                     order_by: Optional[_builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLkeClustersResult:
    """
    Provides information about a list of current Linode Kubernetes (LKE) clusters on your account that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-lke-clusters).

    ## Example Usage

    Get information about all LKE clusters with a specific tag:

    ```python
    import pulumi
    import pulumi_linode as linode

    specific = linode.get_lke_clusters(filters=[{
        "name": "tags",
        "values": ["test-tag"],
    }])
    pulumi.export("lkeCluster", specific.lke_clusters[0].id)
    ```

    ## Filterable Fields

    * `k8s_version`

    * `label`

    * `region`

    * `tags`

    * `status`

    * `created`

    * `updated`


    :param _builtins.str order: The order in which results should be returned. (`asc`, `desc`; default `asc`)
    :param _builtins.str order_by: The attribute to order the results by. See the Filterable Fields section for a list of valid fields.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['lkeClusters'] = lke_clusters
    __args__['order'] = order
    __args__['orderBy'] = order_by
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getLkeClusters:getLkeClusters', __args__, opts=opts, typ=GetLkeClustersResult).value

    return AwaitableGetLkeClustersResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        lke_clusters=pulumi.get(__ret__, 'lke_clusters'),
        order=pulumi.get(__ret__, 'order'),
        order_by=pulumi.get(__ret__, 'order_by'))
def get_lke_clusters_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetLkeClustersFilterArgs', 'GetLkeClustersFilterArgsDict']]]]] = None,
                            lke_clusters: Optional[pulumi.Input[Optional[Sequence[Union['GetLkeClustersLkeClusterArgs', 'GetLkeClustersLkeClusterArgsDict']]]]] = None,
                            order: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            order_by: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLkeClustersResult]:
    """
    Provides information about a list of current Linode Kubernetes (LKE) clusters on your account that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-lke-clusters).

    ## Example Usage

    Get information about all LKE clusters with a specific tag:

    ```python
    import pulumi
    import pulumi_linode as linode

    specific = linode.get_lke_clusters(filters=[{
        "name": "tags",
        "values": ["test-tag"],
    }])
    pulumi.export("lkeCluster", specific.lke_clusters[0].id)
    ```

    ## Filterable Fields

    * `k8s_version`

    * `label`

    * `region`

    * `tags`

    * `status`

    * `created`

    * `updated`


    :param _builtins.str order: The order in which results should be returned. (`asc`, `desc`; default `asc`)
    :param _builtins.str order_by: The attribute to order the results by. See the Filterable Fields section for a list of valid fields.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['lkeClusters'] = lke_clusters
    __args__['order'] = order
    __args__['orderBy'] = order_by
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getLkeClusters:getLkeClusters', __args__, opts=opts, typ=GetLkeClustersResult)
    return __ret__.apply(lambda __response__: GetLkeClustersResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        lke_clusters=pulumi.get(__response__, 'lke_clusters'),
        order=pulumi.get(__response__, 'order'),
        order_by=pulumi.get(__response__, 'order_by')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetNetworkingIpResult',
    'AwaitableGetNetworkingIpResult',
    'get_networking_ip',
    'get_networking_ip_output',
]

@pulumi.output_type
class GetNetworkingIpResult:
    """
    A collection of values returned by getNetworkingIp.
    """
    def __init__(__self__, address=None, gateway=None, id=None, interface_id=None, linode_id=None, prefix=None, public=None, rdns=None, region=None, reserved=None, subnet_mask=None, type=None, vpc_nat11=None):
        if address and not isinstance(address, str):
            raise TypeError("Expected argument 'address' to be a str")
        pulumi.set(__self__, "address", address)
        if gateway and not isinstance(gateway, str):
            raise TypeError("Expected argument 'gateway' to be a str")
        pulumi.set(__self__, "gateway", gateway)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if interface_id and not isinstance(interface_id, int):
            raise TypeError("Expected argument 'interface_id' to be a int")
        pulumi.set(__self__, "interface_id", interface_id)
        if linode_id and not isinstance(linode_id, int):
            raise TypeError("Expected argument 'linode_id' to be a int")
        pulumi.set(__self__, "linode_id", linode_id)
        if prefix and not isinstance(prefix, int):
            raise TypeError("Expected argument 'prefix' to be a int")
        pulumi.set(__self__, "prefix", prefix)
        if public and not isinstance(public, bool):
            raise TypeError("Expected argument 'public' to be a bool")
        pulumi.set(__self__, "public", public)
        if rdns and not isinstance(rdns, str):
            raise TypeError("Expected argument 'rdns' to be a str")
        pulumi.set(__self__, "rdns", rdns)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if reserved and not isinstance(reserved, bool):
            raise TypeError("Expected argument 'reserved' to be a bool")
        pulumi.set(__self__, "reserved", reserved)
        if subnet_mask and not isinstance(subnet_mask, str):
            raise TypeError("Expected argument 'subnet_mask' to be a str")
        pulumi.set(__self__, "subnet_mask", subnet_mask)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if vpc_nat11 and not isinstance(vpc_nat11, dict):
            raise TypeError("Expected argument 'vpc_nat11' to be a dict")
        pulumi.set(__self__, "vpc_nat11", vpc_nat11)

    @_builtins.property
    @pulumi.getter
    def address(self) -> _builtins.str:
        """
        The IPv4 address that is configured as a 1:1 NAT for this VPC interface.
        """
        return pulumi.get(self, "address")

    @_builtins.property
    @pulumi.getter
    def gateway(self) -> _builtins.str:
        """
        The default gateway for this address.
        """
        return pulumi.get(self, "gateway")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="interfaceId")
    def interface_id(self) -> _builtins.int:
        """
        The ID of the interface this address is assigned to.
        """
        return pulumi.get(self, "interface_id")

    @_builtins.property
    @pulumi.getter(name="linodeId")
    def linode_id(self) -> _builtins.int:
        """
        The ID of the Linode this address currently belongs to.
        """
        return pulumi.get(self, "linode_id")

    @_builtins.property
    @pulumi.getter
    def prefix(self) -> _builtins.int:
        """
        The number of bits set in the subnet mask.
        """
        return pulumi.get(self, "prefix")

    @_builtins.property
    @pulumi.getter
    def public(self) -> _builtins.bool:
        """
        Whether this is a public or private IP address.
        """
        return pulumi.get(self, "public")

    @_builtins.property
    @pulumi.getter
    def rdns(self) -> _builtins.str:
        """
        The reverse DNS assigned to this address. For public IPv4 addresses, this will be set to a default value provided by Linode if not explicitly set.
        """
        return pulumi.get(self, "rdns")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The Region this IP address resides in. See all regions [here](https://api.linode.com/v4/regions).
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def reserved(self) -> _builtins.bool:
        """
        Whether this IP address is a reserved IP.
        """
        return pulumi.get(self, "reserved")

    @_builtins.property
    @pulumi.getter(name="subnetMask")
    def subnet_mask(self) -> _builtins.str:
        """
        The mask that separates host bits from network bits for this address.
        """
        return pulumi.get(self, "subnet_mask")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of address this is (ipv4, ipv6, ipv6/pool, ipv6/range).
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="vpcNat11")
    def vpc_nat11(self) -> 'outputs.GetNetworkingIpVpcNat11Result':
        """
        Contains information about the NAT 1:1 mapping of a public IP address to a VPC subnet.
        """
        return pulumi.get(self, "vpc_nat11")


class AwaitableGetNetworkingIpResult(GetNetworkingIpResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkingIpResult(
            address=self.address,
            gateway=self.gateway,
            id=self.id,
            interface_id=self.interface_id,
            linode_id=self.linode_id,
            prefix=self.prefix,
            public=self.public,
            rdns=self.rdns,
            region=self.region,
            reserved=self.reserved,
            subnet_mask=self.subnet_mask,
            type=self.type,
            vpc_nat11=self.vpc_nat11)


def get_networking_ip(address: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkingIpResult:
    """
    Provides information about a Linode Networking IP Address
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-ip).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode Networking IP Address.

    ```python
    import pulumi
    import pulumi_linode as linode

    ns1_linode_com = linode.get_networking_ip(address="162.159.27.72")
    ```


    :param _builtins.str address: The IP Address to access.  The address must be associated with the account and a resource that the user has access to view.
    """
    __args__ = dict()
    __args__['address'] = address
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getNetworkingIp:getNetworkingIp', __args__, opts=opts, typ=GetNetworkingIpResult).value

    return AwaitableGetNetworkingIpResult(
        address=pulumi.get(__ret__, 'address'),
        gateway=pulumi.get(__ret__, 'gateway'),
        id=pulumi.get(__ret__, 'id'),
        interface_id=pulumi.get(__ret__, 'interface_id'),
        linode_id=pulumi.get(__ret__, 'linode_id'),
        prefix=pulumi.get(__ret__, 'prefix'),
        public=pulumi.get(__ret__, 'public'),
        rdns=pulumi.get(__ret__, 'rdns'),
        region=pulumi.get(__ret__, 'region'),
        reserved=pulumi.get(__ret__, 'reserved'),
        subnet_mask=pulumi.get(__ret__, 'subnet_mask'),
        type=pulumi.get(__ret__, 'type'),
        vpc_nat11=pulumi.get(__ret__, 'vpc_nat11'))
def get_networking_ip_output(address: Optional[pulumi.Input[_builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkingIpResult]:
    """
    Provides information about a Linode Networking IP Address
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-ip).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode Networking IP Address.

    ```python
    import pulumi
    import pulumi_linode as linode

    ns1_linode_com = linode.get_networking_ip(address="162.159.27.72")
    ```


    :param _builtins.str address: The IP Address to access.  The address must be associated with the account and a resource that the user has access to view.
    """
    __args__ = dict()
    __args__['address'] = address
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getNetworkingIp:getNetworkingIp', __args__, opts=opts, typ=GetNetworkingIpResult)
    return __ret__.apply(lambda __response__: GetNetworkingIpResult(
        address=pulumi.get(__response__, 'address'),
        gateway=pulumi.get(__response__, 'gateway'),
        id=pulumi.get(__response__, 'id'),
        interface_id=pulumi.get(__response__, 'interface_id'),
        linode_id=pulumi.get(__response__, 'linode_id'),
        prefix=pulumi.get(__response__, 'prefix'),
        public=pulumi.get(__response__, 'public'),
        rdns=pulumi.get(__response__, 'rdns'),
        region=pulumi.get(__response__, 'region'),
        reserved=pulumi.get(__response__, 'reserved'),
        subnet_mask=pulumi.get(__response__, 'subnet_mask'),
        type=pulumi.get(__response__, 'type'),
        vpc_nat11=pulumi.get(__response__, 'vpc_nat11')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InterfaceArgs', 'Interface']

@pulumi.input_type
class InterfaceArgs:
    def __init__(__self__, *,
                 linode_id: pulumi.Input[_builtins.int],
                 default_route: Optional[pulumi.Input['InterfaceDefaultRouteArgs']] = None,
                 firewall_id: Optional[pulumi.Input[_builtins.int]] = None,
                 public: Optional[pulumi.Input['InterfacePublicArgs']] = None,
                 vlan: Optional[pulumi.Input['InterfaceVlanArgs']] = None,
                 vpc: Optional[pulumi.Input['InterfaceVpcArgs']] = None):
        """
        The set of arguments for constructing a Interface resource.
        :param pulumi.Input[_builtins.int] linode_id: The ID of the Linode to assign this interface to.
        :param pulumi.Input['InterfaceDefaultRouteArgs'] default_route: Indicates if the interface serves as the default route when multiple interfaces are eligible for this role.
        :param pulumi.Input[_builtins.int] firewall_id: The ID of an enabled firewall to secure a VPC or public interface. Not allowed for VLAN interfaces.
        :param pulumi.Input['InterfacePublicArgs'] public: Nested attributes object for a Linode public interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        :param pulumi.Input['InterfaceVlanArgs'] vlan: Nested attributes object for a Linode VLAN interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        :param pulumi.Input['InterfaceVpcArgs'] vpc: Nested attributes object for a Linode VPC interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        pulumi.set(__self__, "linode_id", linode_id)
        if default_route is not None:
            pulumi.set(__self__, "default_route", default_route)
        if firewall_id is not None:
            pulumi.set(__self__, "firewall_id", firewall_id)
        if public is not None:
            pulumi.set(__self__, "public", public)
        if vlan is not None:
            pulumi.set(__self__, "vlan", vlan)
        if vpc is not None:
            pulumi.set(__self__, "vpc", vpc)

    @_builtins.property
    @pulumi.getter(name="linodeId")
    def linode_id(self) -> pulumi.Input[_builtins.int]:
        """
        The ID of the Linode to assign this interface to.
        """
        return pulumi.get(self, "linode_id")

    @linode_id.setter
    def linode_id(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "linode_id", value)

    @_builtins.property
    @pulumi.getter(name="defaultRoute")
    def default_route(self) -> Optional[pulumi.Input['InterfaceDefaultRouteArgs']]:
        """
        Indicates if the interface serves as the default route when multiple interfaces are eligible for this role.
        """
        return pulumi.get(self, "default_route")

    @default_route.setter
    def default_route(self, value: Optional[pulumi.Input['InterfaceDefaultRouteArgs']]):
        pulumi.set(self, "default_route", value)

    @_builtins.property
    @pulumi.getter(name="firewallId")
    def firewall_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of an enabled firewall to secure a VPC or public interface. Not allowed for VLAN interfaces.
        """
        return pulumi.get(self, "firewall_id")

    @firewall_id.setter
    def firewall_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "firewall_id", value)

    @_builtins.property
    @pulumi.getter
    def public(self) -> Optional[pulumi.Input['InterfacePublicArgs']]:
        """
        Nested attributes object for a Linode public interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        return pulumi.get(self, "public")

    @public.setter
    def public(self, value: Optional[pulumi.Input['InterfacePublicArgs']]):
        pulumi.set(self, "public", value)

    @_builtins.property
    @pulumi.getter
    def vlan(self) -> Optional[pulumi.Input['InterfaceVlanArgs']]:
        """
        Nested attributes object for a Linode VLAN interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        return pulumi.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: Optional[pulumi.Input['InterfaceVlanArgs']]):
        pulumi.set(self, "vlan", value)

    @_builtins.property
    @pulumi.getter
    def vpc(self) -> Optional[pulumi.Input['InterfaceVpcArgs']]:
        """
        Nested attributes object for a Linode VPC interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        return pulumi.get(self, "vpc")

    @vpc.setter
    def vpc(self, value: Optional[pulumi.Input['InterfaceVpcArgs']]):
        pulumi.set(self, "vpc", value)


@pulumi.input_type
class _InterfaceState:
    def __init__(__self__, *,
                 default_route: Optional[pulumi.Input['InterfaceDefaultRouteArgs']] = None,
                 firewall_id: Optional[pulumi.Input[_builtins.int]] = None,
                 linode_id: Optional[pulumi.Input[_builtins.int]] = None,
                 public: Optional[pulumi.Input['InterfacePublicArgs']] = None,
                 vlan: Optional[pulumi.Input['InterfaceVlanArgs']] = None,
                 vpc: Optional[pulumi.Input['InterfaceVpcArgs']] = None):
        """
        Input properties used for looking up and filtering Interface resources.
        :param pulumi.Input['InterfaceDefaultRouteArgs'] default_route: Indicates if the interface serves as the default route when multiple interfaces are eligible for this role.
        :param pulumi.Input[_builtins.int] firewall_id: The ID of an enabled firewall to secure a VPC or public interface. Not allowed for VLAN interfaces.
        :param pulumi.Input[_builtins.int] linode_id: The ID of the Linode to assign this interface to.
        :param pulumi.Input['InterfacePublicArgs'] public: Nested attributes object for a Linode public interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        :param pulumi.Input['InterfaceVlanArgs'] vlan: Nested attributes object for a Linode VLAN interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        :param pulumi.Input['InterfaceVpcArgs'] vpc: Nested attributes object for a Linode VPC interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        if default_route is not None:
            pulumi.set(__self__, "default_route", default_route)
        if firewall_id is not None:
            pulumi.set(__self__, "firewall_id", firewall_id)
        if linode_id is not None:
            pulumi.set(__self__, "linode_id", linode_id)
        if public is not None:
            pulumi.set(__self__, "public", public)
        if vlan is not None:
            pulumi.set(__self__, "vlan", vlan)
        if vpc is not None:
            pulumi.set(__self__, "vpc", vpc)

    @_builtins.property
    @pulumi.getter(name="defaultRoute")
    def default_route(self) -> Optional[pulumi.Input['InterfaceDefaultRouteArgs']]:
        """
        Indicates if the interface serves as the default route when multiple interfaces are eligible for this role.
        """
        return pulumi.get(self, "default_route")

    @default_route.setter
    def default_route(self, value: Optional[pulumi.Input['InterfaceDefaultRouteArgs']]):
        pulumi.set(self, "default_route", value)

    @_builtins.property
    @pulumi.getter(name="firewallId")
    def firewall_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of an enabled firewall to secure a VPC or public interface. Not allowed for VLAN interfaces.
        """
        return pulumi.get(self, "firewall_id")

    @firewall_id.setter
    def firewall_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "firewall_id", value)

    @_builtins.property
    @pulumi.getter(name="linodeId")
    def linode_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of the Linode to assign this interface to.
        """
        return pulumi.get(self, "linode_id")

    @linode_id.setter
    def linode_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "linode_id", value)

    @_builtins.property
    @pulumi.getter
    def public(self) -> Optional[pulumi.Input['InterfacePublicArgs']]:
        """
        Nested attributes object for a Linode public interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        return pulumi.get(self, "public")

    @public.setter
    def public(self, value: Optional[pulumi.Input['InterfacePublicArgs']]):
        pulumi.set(self, "public", value)

    @_builtins.property
    @pulumi.getter
    def vlan(self) -> Optional[pulumi.Input['InterfaceVlanArgs']]:
        """
        Nested attributes object for a Linode VLAN interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        return pulumi.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: Optional[pulumi.Input['InterfaceVlanArgs']]):
        pulumi.set(self, "vlan", value)

    @_builtins.property
    @pulumi.getter
    def vpc(self) -> Optional[pulumi.Input['InterfaceVpcArgs']]:
        """
        Nested attributes object for a Linode VPC interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        return pulumi.get(self, "vpc")

    @vpc.setter
    def vpc(self, value: Optional[pulumi.Input['InterfaceVpcArgs']]):
        pulumi.set(self, "vpc", value)


@pulumi.type_token("linode:index/interface:Interface")
class Interface(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_route: Optional[pulumi.Input[Union['InterfaceDefaultRouteArgs', 'InterfaceDefaultRouteArgsDict']]] = None,
                 firewall_id: Optional[pulumi.Input[_builtins.int]] = None,
                 linode_id: Optional[pulumi.Input[_builtins.int]] = None,
                 public: Optional[pulumi.Input[Union['InterfacePublicArgs', 'InterfacePublicArgsDict']]] = None,
                 vlan: Optional[pulumi.Input[Union['InterfaceVlanArgs', 'InterfaceVlanArgsDict']]] = None,
                 vpc: Optional[pulumi.Input[Union['InterfaceVpcArgs', 'InterfaceVpcArgsDict']]] = None,
                 __props__=None):
        """
        Provides a Linode Interface resource that can be used to create, modify, and delete network interfaces for Linode instances. Interfaces allow you to configure public, VLAN, and VPC networking for your Linode instances.

        This resource is specifically for Linode interfaces. If you are interested in deploying a Linode instance with a legacy config interface, please refer to the `InstanceConfig` resource documentation for details.

        This resource is designed to work with explicitly defined disk and config resources for the Linode instance. See the Complete Example with Linode section below for details.

        For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/post-linode-instance-interface).

        ## Example Usage

        ### Public Interface Example

        The following example shows how to create a public interface with specific IPv4 and IPv6 configurations.

        ```python
        import pulumi
        import pulumi_linode as linode

        public = linode.Interface("public",
            linode_id=my_instance["id"],
            public={
                "ipv4": {
                    "addresses": [{
                        "address": "auto",
                        "primary": True,
                    }],
                },
                "ipv6": {
                    "ranges": [{
                        "range": "/64",
                    }],
                },
            })
        ```

        ### IPv6-Only Public Interface Example

        The following example shows how to create an IPv6-only public interface. Note that you must explicitly set `addresses = []` to prevent the automatic creation of an IPv4 address.

        ```python
        import pulumi
        import pulumi_linode as linode

        ipv6_only = linode.Interface("ipv6_only",
            linode_id=my_instance["id"],
            public={
                "ipv4": {
                    "addresses": [],
                },
                "ipv6": {
                    "ranges": [{
                        "range": "/64",
                    }],
                },
            })
        ```

        ### VPC Interface Example

        The following example shows how to create a VPC interface with custom IPv4 configuration and 1:1 NAT.

        ```python
        import pulumi
        import pulumi_linode as linode

        vpc = linode.Interface("vpc",
            linode_id=my_instance["id"],
            vpc={
                "subnet_id": 240213,
                "ipv4": {
                    "addresses": [{
                        "address": "auto",
                    }],
                    "ranges": [{
                        "range": "/32",
                    }],
                },
            })
        ```

        ### VPC (IPv6) Interface Example

        The following example shows how to create a public VPC interface with a custom IPv6 configuration.

        ```python
        import pulumi
        import pulumi_linode as linode

        vpc = linode.Interface("vpc",
            linode_id=my_instance["id"],
            vpc={
                "subnet_id": 12345,
                "ipv6": {
                    "is_public": True,
                    "slaacs": [{
                        "range": "auto",
                    }],
                    "ranges": [{
                        "range": "auto",
                    }],
                },
            })
        ```

        ### VLAN Interface Example

        The following example shows how to create a VLAN interface.

        ```python
        import pulumi
        import pulumi_linode as linode

        vlan = linode.Interface("vlan",
            linode_id=web["id"],
            vlan={
                "vlan_label": "web-vlan",
                "ipam_address": "192.168.200.5/24",
            })
        ```

        ### Complete Example with Linode

        ## Notes

        * Each Linode instance can have up to 3 network interfaces.
        * VLAN interfaces cannot be updated after creation and require recreation.
        * VPC subnet IDs cannot be changed after interface creation.
        * Firewall IDs are only supported for public and VPC interfaces, not for VLAN interfaces.
        * When configuring multiple interfaces, use the `default_route` setting to specify which interface should handle default routing.

        ## Import

        Interfaces can be imported using a Linode ID followed by an Interface ID, separated by a comma, e.g.

        ```sh
        $ pulumi import linode:index/interface:Interface example 12345,67890
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['InterfaceDefaultRouteArgs', 'InterfaceDefaultRouteArgsDict']] default_route: Indicates if the interface serves as the default route when multiple interfaces are eligible for this role.
        :param pulumi.Input[_builtins.int] firewall_id: The ID of an enabled firewall to secure a VPC or public interface. Not allowed for VLAN interfaces.
        :param pulumi.Input[_builtins.int] linode_id: The ID of the Linode to assign this interface to.
        :param pulumi.Input[Union['InterfacePublicArgs', 'InterfacePublicArgsDict']] public: Nested attributes object for a Linode public interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        :param pulumi.Input[Union['InterfaceVlanArgs', 'InterfaceVlanArgsDict']] vlan: Nested attributes object for a Linode VLAN interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        :param pulumi.Input[Union['InterfaceVpcArgs', 'InterfaceVpcArgsDict']] vpc: Nested attributes object for a Linode VPC interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InterfaceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Linode Interface resource that can be used to create, modify, and delete network interfaces for Linode instances. Interfaces allow you to configure public, VLAN, and VPC networking for your Linode instances.

        This resource is specifically for Linode interfaces. If you are interested in deploying a Linode instance with a legacy config interface, please refer to the `InstanceConfig` resource documentation for details.

        This resource is designed to work with explicitly defined disk and config resources for the Linode instance. See the Complete Example with Linode section below for details.

        For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/post-linode-instance-interface).

        ## Example Usage

        ### Public Interface Example

        The following example shows how to create a public interface with specific IPv4 and IPv6 configurations.

        ```python
        import pulumi
        import pulumi_linode as linode

        public = linode.Interface("public",
            linode_id=my_instance["id"],
            public={
                "ipv4": {
                    "addresses": [{
                        "address": "auto",
                        "primary": True,
                    }],
                },
                "ipv6": {
                    "ranges": [{
                        "range": "/64",
                    }],
                },
            })
        ```

        ### IPv6-Only Public Interface Example

        The following example shows how to create an IPv6-only public interface. Note that you must explicitly set `addresses = []` to prevent the automatic creation of an IPv4 address.

        ```python
        import pulumi
        import pulumi_linode as linode

        ipv6_only = linode.Interface("ipv6_only",
            linode_id=my_instance["id"],
            public={
                "ipv4": {
                    "addresses": [],
                },
                "ipv6": {
                    "ranges": [{
                        "range": "/64",
                    }],
                },
            })
        ```

        ### VPC Interface Example

        The following example shows how to create a VPC interface with custom IPv4 configuration and 1:1 NAT.

        ```python
        import pulumi
        import pulumi_linode as linode

        vpc = linode.Interface("vpc",
            linode_id=my_instance["id"],
            vpc={
                "subnet_id": 240213,
                "ipv4": {
                    "addresses": [{
                        "address": "auto",
                    }],
                    "ranges": [{
                        "range": "/32",
                    }],
                },
            })
        ```

        ### VPC (IPv6) Interface Example

        The following example shows how to create a public VPC interface with a custom IPv6 configuration.

        ```python
        import pulumi
        import pulumi_linode as linode

        vpc = linode.Interface("vpc",
            linode_id=my_instance["id"],
            vpc={
                "subnet_id": 12345,
                "ipv6": {
                    "is_public": True,
                    "slaacs": [{
                        "range": "auto",
                    }],
                    "ranges": [{
                        "range": "auto",
                    }],
                },
            })
        ```

        ### VLAN Interface Example

        The following example shows how to create a VLAN interface.

        ```python
        import pulumi
        import pulumi_linode as linode

        vlan = linode.Interface("vlan",
            linode_id=web["id"],
            vlan={
                "vlan_label": "web-vlan",
                "ipam_address": "192.168.200.5/24",
            })
        ```

        ### Complete Example with Linode

        ## Notes

        * Each Linode instance can have up to 3 network interfaces.
        * VLAN interfaces cannot be updated after creation and require recreation.
        * VPC subnet IDs cannot be changed after interface creation.
        * Firewall IDs are only supported for public and VPC interfaces, not for VLAN interfaces.
        * When configuring multiple interfaces, use the `default_route` setting to specify which interface should handle default routing.

        ## Import

        Interfaces can be imported using a Linode ID followed by an Interface ID, separated by a comma, e.g.

        ```sh
        $ pulumi import linode:index/interface:Interface example 12345,67890
        ```

        :param str resource_name: The name of the resource.
        :param InterfaceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InterfaceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_route: Optional[pulumi.Input[Union['InterfaceDefaultRouteArgs', 'InterfaceDefaultRouteArgsDict']]] = None,
                 firewall_id: Optional[pulumi.Input[_builtins.int]] = None,
                 linode_id: Optional[pulumi.Input[_builtins.int]] = None,
                 public: Optional[pulumi.Input[Union['InterfacePublicArgs', 'InterfacePublicArgsDict']]] = None,
                 vlan: Optional[pulumi.Input[Union['InterfaceVlanArgs', 'InterfaceVlanArgsDict']]] = None,
                 vpc: Optional[pulumi.Input[Union['InterfaceVpcArgs', 'InterfaceVpcArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InterfaceArgs.__new__(InterfaceArgs)

            __props__.__dict__["default_route"] = default_route
            __props__.__dict__["firewall_id"] = firewall_id
            if linode_id is None and not opts.urn:
                raise TypeError("Missing required property 'linode_id'")
            __props__.__dict__["linode_id"] = linode_id
            __props__.__dict__["public"] = public
            __props__.__dict__["vlan"] = vlan
            __props__.__dict__["vpc"] = vpc
        super(Interface, __self__).__init__(
            'linode:index/interface:Interface',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            default_route: Optional[pulumi.Input[Union['InterfaceDefaultRouteArgs', 'InterfaceDefaultRouteArgsDict']]] = None,
            firewall_id: Optional[pulumi.Input[_builtins.int]] = None,
            linode_id: Optional[pulumi.Input[_builtins.int]] = None,
            public: Optional[pulumi.Input[Union['InterfacePublicArgs', 'InterfacePublicArgsDict']]] = None,
            vlan: Optional[pulumi.Input[Union['InterfaceVlanArgs', 'InterfaceVlanArgsDict']]] = None,
            vpc: Optional[pulumi.Input[Union['InterfaceVpcArgs', 'InterfaceVpcArgsDict']]] = None) -> 'Interface':
        """
        Get an existing Interface resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['InterfaceDefaultRouteArgs', 'InterfaceDefaultRouteArgsDict']] default_route: Indicates if the interface serves as the default route when multiple interfaces are eligible for this role.
        :param pulumi.Input[_builtins.int] firewall_id: The ID of an enabled firewall to secure a VPC or public interface. Not allowed for VLAN interfaces.
        :param pulumi.Input[_builtins.int] linode_id: The ID of the Linode to assign this interface to.
        :param pulumi.Input[Union['InterfacePublicArgs', 'InterfacePublicArgsDict']] public: Nested attributes object for a Linode public interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        :param pulumi.Input[Union['InterfaceVlanArgs', 'InterfaceVlanArgsDict']] vlan: Nested attributes object for a Linode VLAN interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        :param pulumi.Input[Union['InterfaceVpcArgs', 'InterfaceVpcArgsDict']] vpc: Nested attributes object for a Linode VPC interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InterfaceState.__new__(_InterfaceState)

        __props__.__dict__["default_route"] = default_route
        __props__.__dict__["firewall_id"] = firewall_id
        __props__.__dict__["linode_id"] = linode_id
        __props__.__dict__["public"] = public
        __props__.__dict__["vlan"] = vlan
        __props__.__dict__["vpc"] = vpc
        return Interface(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="defaultRoute")
    def default_route(self) -> pulumi.Output['outputs.InterfaceDefaultRoute']:
        """
        Indicates if the interface serves as the default route when multiple interfaces are eligible for this role.
        """
        return pulumi.get(self, "default_route")

    @_builtins.property
    @pulumi.getter(name="firewallId")
    def firewall_id(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The ID of an enabled firewall to secure a VPC or public interface. Not allowed for VLAN interfaces.
        """
        return pulumi.get(self, "firewall_id")

    @_builtins.property
    @pulumi.getter(name="linodeId")
    def linode_id(self) -> pulumi.Output[_builtins.int]:
        """
        The ID of the Linode to assign this interface to.
        """
        return pulumi.get(self, "linode_id")

    @_builtins.property
    @pulumi.getter
    def public(self) -> pulumi.Output[Optional['outputs.InterfacePublic']]:
        """
        Nested attributes object for a Linode public interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        return pulumi.get(self, "public")

    @_builtins.property
    @pulumi.getter
    def vlan(self) -> pulumi.Output[Optional['outputs.InterfaceVlan']]:
        """
        Nested attributes object for a Linode VLAN interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        return pulumi.get(self, "vlan")

    @_builtins.property
    @pulumi.getter
    def vpc(self) -> pulumi.Output[Optional['outputs.InterfaceVpc']]:
        """
        Nested attributes object for a Linode VPC interface. Exactly one of `public`, `vlan`, or `vpc` must be specified.
        """
        return pulumi.get(self, "vpc")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetDomainResult',
    'AwaitableGetDomainResult',
    'get_domain',
    'get_domain_output',
]

@pulumi.output_type
class GetDomainResult:
    """
    A collection of values returned by getDomain.
    """
    def __init__(__self__, axfr_ips=None, description=None, domain=None, expire_sec=None, group=None, id=None, master_ips=None, refresh_sec=None, retry_sec=None, soa_email=None, status=None, tags=None, ttl_sec=None, type=None):
        if axfr_ips and not isinstance(axfr_ips, list):
            raise TypeError("Expected argument 'axfr_ips' to be a list")
        pulumi.set(__self__, "axfr_ips", axfr_ips)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if expire_sec and not isinstance(expire_sec, int):
            raise TypeError("Expected argument 'expire_sec' to be a int")
        pulumi.set(__self__, "expire_sec", expire_sec)
        if group and not isinstance(group, str):
            raise TypeError("Expected argument 'group' to be a str")
        pulumi.set(__self__, "group", group)
        if id and not isinstance(id, int):
            raise TypeError("Expected argument 'id' to be a int")
        pulumi.set(__self__, "id", id)
        if master_ips and not isinstance(master_ips, list):
            raise TypeError("Expected argument 'master_ips' to be a list")
        pulumi.set(__self__, "master_ips", master_ips)
        if refresh_sec and not isinstance(refresh_sec, int):
            raise TypeError("Expected argument 'refresh_sec' to be a int")
        pulumi.set(__self__, "refresh_sec", refresh_sec)
        if retry_sec and not isinstance(retry_sec, int):
            raise TypeError("Expected argument 'retry_sec' to be a int")
        pulumi.set(__self__, "retry_sec", retry_sec)
        if soa_email and not isinstance(soa_email, str):
            raise TypeError("Expected argument 'soa_email' to be a str")
        pulumi.set(__self__, "soa_email", soa_email)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if ttl_sec and not isinstance(ttl_sec, int):
            raise TypeError("Expected argument 'ttl_sec' to be a int")
        pulumi.set(__self__, "ttl_sec", ttl_sec)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="axfrIps")
    def axfr_ips(self) -> Sequence[_builtins.str]:
        """
        The list of IPs that may perform a zone transfer for this Domain.
        """
        return pulumi.get(self, "axfr_ips")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        A description for this Domain.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def domain(self) -> Optional[_builtins.str]:
        """
        The domain this Domain represents. These must be unique in our system; you cannot have two Domains representing the same domain
        """
        return pulumi.get(self, "domain")

    @_builtins.property
    @pulumi.getter(name="expireSec")
    def expire_sec(self) -> _builtins.int:
        """
        The amount of time in seconds that may pass before this Domain is no longer authoritative.
        """
        return pulumi.get(self, "expire_sec")

    @_builtins.property
    @pulumi.getter
    def group(self) -> _builtins.str:
        """
        The group this Domain belongs to.
        """
        return pulumi.get(self, "group")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.int]:
        """
        The unique ID of this Domain.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="masterIps")
    def master_ips(self) -> Sequence[_builtins.str]:
        """
        The IP addresses representing the master DNS for this Domain.
        """
        return pulumi.get(self, "master_ips")

    @_builtins.property
    @pulumi.getter(name="refreshSec")
    def refresh_sec(self) -> _builtins.int:
        """
        The amount of time in seconds before this Domain should be refreshed.
        """
        return pulumi.get(self, "refresh_sec")

    @_builtins.property
    @pulumi.getter(name="retrySec")
    def retry_sec(self) -> _builtins.int:
        """
        The interval, in seconds, at which a failed refresh should be retried.
        """
        return pulumi.get(self, "retry_sec")

    @_builtins.property
    @pulumi.getter(name="soaEmail")
    def soa_email(self) -> _builtins.str:
        """
        Start of Authority email address.
        """
        return pulumi.get(self, "soa_email")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Used to control whether this Domain is currently being rendered. (`disabled`, `active`)
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        An array of tags applied to this object. Tags are case-insensitive and are for organizational purposes only.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="ttlSec")
    def ttl_sec(self) -> _builtins.int:
        """
        'Time to Live'-the amount of time in seconds that this Domain's records may be cached by resolvers or other domain servers.
        """
        return pulumi.get(self, "ttl_sec")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        If this Domain represents the authoritative source of information for the domain it describes, or if it is a read-only copy of a master (also called a slave) (`master`, `slave`)
        """
        return pulumi.get(self, "type")


class AwaitableGetDomainResult(GetDomainResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDomainResult(
            axfr_ips=self.axfr_ips,
            description=self.description,
            domain=self.domain,
            expire_sec=self.expire_sec,
            group=self.group,
            id=self.id,
            master_ips=self.master_ips,
            refresh_sec=self.refresh_sec,
            retry_sec=self.retry_sec,
            soa_email=self.soa_email,
            status=self.status,
            tags=self.tags,
            ttl_sec=self.ttl_sec,
            type=self.type)


def get_domain(domain: Optional[_builtins.str] = None,
               id: Optional[_builtins.int] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDomainResult:
    """
    Provides information about a Linode domain.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-domain).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode domain.

    ```python
    import pulumi
    import pulumi_linode as linode

    foo = linode.get_domain(id=1234567)
    bar = linode.get_domain(domain="bar.example.com")
    ```


    :param _builtins.str domain: The unique domain name of the Domain record to query.
    :param _builtins.int id: The unique numeric ID of the Domain record to query.
    """
    __args__ = dict()
    __args__['domain'] = domain
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getDomain:getDomain', __args__, opts=opts, typ=GetDomainResult).value

    return AwaitableGetDomainResult(
        axfr_ips=pulumi.get(__ret__, 'axfr_ips'),
        description=pulumi.get(__ret__, 'description'),
        domain=pulumi.get(__ret__, 'domain'),
        expire_sec=pulumi.get(__ret__, 'expire_sec'),
        group=pulumi.get(__ret__, 'group'),
        id=pulumi.get(__ret__, 'id'),
        master_ips=pulumi.get(__ret__, 'master_ips'),
        refresh_sec=pulumi.get(__ret__, 'refresh_sec'),
        retry_sec=pulumi.get(__ret__, 'retry_sec'),
        soa_email=pulumi.get(__ret__, 'soa_email'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        ttl_sec=pulumi.get(__ret__, 'ttl_sec'),
        type=pulumi.get(__ret__, 'type'))
def get_domain_output(domain: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      id: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDomainResult]:
    """
    Provides information about a Linode domain.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-domain).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode domain.

    ```python
    import pulumi
    import pulumi_linode as linode

    foo = linode.get_domain(id=1234567)
    bar = linode.get_domain(domain="bar.example.com")
    ```


    :param _builtins.str domain: The unique domain name of the Domain record to query.
    :param _builtins.int id: The unique numeric ID of the Domain record to query.
    """
    __args__ = dict()
    __args__['domain'] = domain
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getDomain:getDomain', __args__, opts=opts, typ=GetDomainResult)
    return __ret__.apply(lambda __response__: GetDomainResult(
        axfr_ips=pulumi.get(__response__, 'axfr_ips'),
        description=pulumi.get(__response__, 'description'),
        domain=pulumi.get(__response__, 'domain'),
        expire_sec=pulumi.get(__response__, 'expire_sec'),
        group=pulumi.get(__response__, 'group'),
        id=pulumi.get(__response__, 'id'),
        master_ips=pulumi.get(__response__, 'master_ips'),
        refresh_sec=pulumi.get(__response__, 'refresh_sec'),
        retry_sec=pulumi.get(__response__, 'retry_sec'),
        soa_email=pulumi.get(__response__, 'soa_email'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        ttl_sec=pulumi.get(__response__, 'ttl_sec'),
        type=pulumi.get(__response__, 'type')))
